--[[	*** Historia ***
Written by : Yukyuk, EU-Moonglade
--]]

-------------------------------------------------------------------------------
--  From _Global to local.
-------------------------------------------------------------------------------
local _G = _G


-------------------------------------------------------------------------------
--  AddOn namespace.
-------------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local cfg = private.cfg
local addon = cfg.addon_name


-------------------------------------------------------------------------------
--  Libstubs.
-------------------------------------------------------------------------------
local L 		= LibStub("AceLocale-3.0"):GetLocale("Historia")
local LibQTip 	= LibStub:GetLibrary("LibQTip-1.0")


-------------------------------------------------------------------------------
--	Local constants
-------------------------------------------------------------------------------
local row_count = 0
local Historia_HC_NO_SCROLLBUTTONS = 24		--  number of scroll buttons for the currency frame
local Historia_NUMBEROFCURRENCYTABS = 3		--	number of selection buttons in the currency tab
local Historia_Currency_Tab = {}			--	this variable holds the selection buttons
local Historia_Currency_Table = {}			--	this varaible holds the currency dates selected from the database
local Historia_Currency_Scroll_Table = {}	--	this variable holds the selected lines that go into the scroll table

--  Define the icons of the currency tab .
 local Currency_icon = {
	[1] = "Interface\\ICONS\\INV_Misc_Coin_05",
	[2] = "Interface\\ICONS\\INV_Misc_Coin_03",
	[3] = "Interface\\ICONS\\INV_Misc_Coin_01",	
}

local Historia_NUMBER_OF_YEARS = 10
local Historia_NUMBER_OF_MONTHS = 12
local Historia_NUMBER_OF_DAYS = 31
local DTY = {"2015", "2016", "2017", "2018", "2019", "2020", "2021", "2022", "2023", "2024"}
local DTM = {"01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12"}
local DTD = {"01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31"}

local amount = 0

--	These table hold the Best/Worst Day/Months values
--	For the days it holds 5 values, amount, year, month, day and sign
--	For the months it holds 4 values, amount, year, month and sign
--  The fifth value for the month is not used. Just defined to keep the tables the same size.
local Best_days = {
[1] = {	[1] = -999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[2] = {	[1] = -999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[3] = {	[1] = -999999999,[2] = "",[3] = "",[4] = "",[5] = "",},			
}

local Worst_days = {
[1] = {	[1] = 999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[2] = {	[1] = 999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[3] = {	[1] = 999999999,[2] = "",[3] = "",[4] = "",[5] = "",},				
}

local Best_months = {
[1] = {	[1] = -999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[2] = {	[1] = -999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[3] = {	[1] = -999999999,[2] = "",[3] = "",[4] = "",[5] = "",},				
}

local Worst_months = {
[1] = {	[1] = 999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[2] = {	[1] = 999999999,[2] = "",[3] = "",[4] = "",[5] = "",},
[3] = {	[1] = 999999999,[2] = "",[3] = "",[4] = "",[5] = "",},				
}


--------------------------------------------------------------------------------
--  This is the Historia Currency frame
--------------------------------------------------------------------------------	
function Historia_Currency()
	local Historia_HC = CreateFrame("Frame","Historia_HC",Historia_UI)
	Historia_HC:SetPoint("TOP", "Historia_UI", 0, -16)
	Historia_HC:SetPoint("BOTTOM", "Historia_UI", 0, 16)
	Historia_HC:SetPoint("LEFT", "Historia_UI", 16, 0)
	Historia_HC:SetPoint("RIGHT", "Historia_UI", -16, 0)
	Historia_HC:SetBackdrop(cfg.Historia_backdrop3)
	
	--  Create a frame for the header Currency info.
	local Historia_HC_H = CreateFrame("Frame","Historia_HC_H",Historia_HC)
	Historia_HC_H:SetPoint("TOPLEFT","Historia_HC",0,0)
	Historia_HC_H:SetPoint("BOTTOMRIGHT","Historia_HC","TOPRIGHT",0,-48)
	Historia_HC_H:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HC_H.F1 = Historia_HC_H:CreateFontString(nil,"ARTWORK","GameFontNormalHuge")
	Historia_HC_H.F1:SetPoint("CENTER","Historia_HC_H",0,0)
	Historia_HC_H.F1:SetText(L["History of:"] .. " " .. L["Currency"])	
	
	Historia_Currency_Scrollframe()
	Historia_Currency_TheRest()	

	Historia_HC:Hide()
end	


-------------------------------------------------------------------------------
--  Fill the Currency scroll table
-------------------------------------------------------------------------------
function Historia_Currency_Scrollframe()
	--  Create a reference frame for the rest of the Currency info.
	local Historia_HC_I = CreateFrame("Frame","Historia_HC_I",Historia_HC)
	Historia_HC_I:SetPoint("TOPLEFT", "Historia_HC_H", "BOTTOMLEFT", 0, -16)
	Historia_HC_I:SetPoint("BOTTOMRIGHT", "Historia_HC", "BOTTOMRIGHT", 0, 0)
	local Historia_HC_I_Width = Historia_HC_I:GetWidth()	
	local Historia_HC_I_Height = Historia_HC_I:GetHeight()

	--  Create a frame for the header Currency text.
	local Historia_HC_IH = CreateFrame("Frame","Historia_HC_IH",Historia_HC_I)
	Historia_HC_IH:SetPoint("TOPLEFT","Historia_HC_I",0,0)
	Historia_HC_IH:SetPoint("BOTTOMRIGHT","Historia_HC_I","TOPLEFT",320,-24)
	Historia_HC_IH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HC_IH.F1 = Historia_HC_IH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HC_IH.F1:SetPoint("CENTER","Historia_HC_IH",0,0)
	Historia_HC_IH.F1:SetText(L["Currency"])	
	
	--  Create the container for the Currency scroll frame.
	local HCSF1 = CreateFrame("Frame","HCSF1",Historia_HC_I)
	HCSF1:SetPoint("TOPLEFT", "Historia_HC_I", "TOPLEFT", 0, -24)
	HCSF1:SetPoint("BOTTOMRIGHT", "Historia_HC_I", "TOPLEFT", 320, Historia_HC_I_Height*-1)
	HCSF1:SetBackdrop((cfg.Historia_backdrop2))

	--  Create the container for the Currency scroll bar.
	local HCSF1_bar = CreateFrame("Frame","HCSF1_bar",HCSF1)
	HCSF1_bar:SetPoint("TOPRIGHT", "HCSF1", 0, 0)
	HCSF1_bar:SetPoint("BOTTOMLEFT", "HCSF1", "BOTTOMRIGHT", -24, 0)
	HCSF1_bar:SetBackdrop(cfg.Historia_backdrop2)	

	--  Create the list of buttons that go into the Currency scroll frame
	HCSF1.list = {}
	for i=1,Historia_HC_NO_SCROLLBUTTONS do
		HCSF1.list[i] = CreateFrame("Button",nil,HCSF1)
		HCSF1.list[i]:SetSize(320,16)
		HCSF1.list[i]:SetPoint("TOPLEFT",HCSF1,"TOPLEFT",8,(i-1)*-16-4)
		HCSF1.list[i]:Show()
		
		HCSF1.list[i].name1 = HCSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		HCSF1.list[i].name1:SetSize(160,16)
		HCSF1.list[i].name1:SetPoint("LEFT",0,0)	
		HCSF1.list[i].name1:SetJustifyH("CENTER") 
		
		HCSF1.list[i].icon1 = HCSF1.list[i]:CreateTexture(nil,"ARTWORK")
		HCSF1.list[i].icon1:SetSize(16,16)
		HCSF1.list[i].icon1:SetPoint("LEFT", HCSF1.list[i].name1, "RIGHT", 4, 0)		
	
		HCSF1.list[i].name2 = HCSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		HCSF1.list[i].name2:SetSize(160,16)
		HCSF1.list[i].name2:SetPoint("LEFT", HCSF1.list[i].icon1, "RIGHT",4,0)
		HCSF1.list[i].name2:SetJustifyH("LEFT") 
	end	
	
	-- 	Create the scroll frame
	HCSF1.scrollFrame = CreateFrame("ScrollFrame","HCSF1_scrollFrame",HCSF1,"FauxScrollFrameTemplate")
	HCSF1.scrollFrame:SetPoint("TOPLEFT",HCSF1,"TOPLEFT",0,-2)
	HCSF1.scrollFrame:SetPoint("BOTTOMRIGHT",HCSF1,"BOTTOMRIGHT",-26,2)
	HCSF1.scrollFrame:SetScript("OnVerticalScroll",function(self,offset)
	FauxScrollFrame_OnVerticalScroll(self,offset,16,HCSF1_ScrollFrameUpdate)
	end)	
	
		--	Create the Day/Month/Year gold buttons
	for i = 1,Historia_NUMBEROFCURRENCYTABS do
		Historia_Currency_Tab[i] = CreateFrame("Button",nil,Historia_HC_I)
		Historia_Currency_Tab[i]:SetSize(40,40)
		Historia_Currency_Tab[i]:SetPoint("TOPLEFT",HCSF1,"TOPRIGHT",0,(i-1)*-40)
		Historia_Currency_Tab[i]:SetBackdrop(cfg.Historia_backdrop0)
		Historia_Currency_Tab[i]:Show()
		Historia_Currency_Tab[i]:SetScript("OnClick", function(self, button)
			Historia_HC_Build_Table(i)		
		end)	
		Historia_Currency_Tab[i]:SetScript("OnEnter", function(self, button)
			Historia_Currency_Tab[i].te1:Show()
		end)		
		Historia_Currency_Tab[i]:SetScript("OnLeave", function(self, button)
			Historia_Currency_Tab[i].te1:Hide()
		end)		
		
		Historia_Currency_Tab[i].te1 = Historia_Currency_Tab[i]:CreateTexture(nil,"ARTWORK")
		Historia_Currency_Tab[i].te1:SetTexture("Interface\\ContainerFrame\\UI-Icon-QuestBorder")
		Historia_Currency_Tab[i].te1:SetPoint("TOPLEFT", Historia_Currency_Tab[i], 2, -2)
		Historia_Currency_Tab[i].te1:SetPoint("BOTTOMRIGHT", Historia_Currency_Tab[i], -2, 2)	
		Historia_Currency_Tab[i].te1:Hide()
		
		Historia_Currency_Tab[i].te2 = Historia_Currency_Tab[i]:CreateTexture(nil,"ARTWORK")
		Historia_Currency_Tab[i].te2:SetTexture(Currency_icon[i])
		Historia_Currency_Tab[i].te2:SetPoint("TOPLEFT", Historia_Currency_Tab[i], 4, -4)
		Historia_Currency_Tab[i].te2:SetPoint("BOTTOMRIGHT", Historia_Currency_Tab[i], -4, 4)	
		Historia_Currency_Tab[i].te2:Show()		
	end
end 


-------------------------------------------------------------------------------
--  Build the gold per Day table
-------------------------------------------------------------------------------
function Historia_HC_Build_PerDay()
	row_count = 0
	Historia_Currency_Table = {}
	Historia_Currency_Scroll_Table = {}
	
	for i = 1, Historia_NUMBER_OF_YEARS do
		if HistoriaLocalDb.Dates[DTY[i]] then
			for j = 1, Historia_NUMBER_OF_MONTHS do
				if HistoriaLocalDb.Dates[DTY[i]][DTM[j]] then
					for k = 1, Historia_NUMBER_OF_DAYS do
						if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]] then				
							Historia_Currency_Table = {}
							row_count = row_count + 1
							Historia_Currency_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
							amount = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Current - HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Start
							if amount > 0 then 
								Historia_Currency_Table.Currency = amount
								Historia_Currency_Table.Sign = 1	
							elseif 	amount < 0 then 
								Historia_Currency_Table.Currency = amount * -1
								Historia_Currency_Table.Sign = -1	
							elseif 	amount == 0 then 
								Historia_Currency_Table.Currency = amount
								Historia_Currency_Table.Sign = 0	
							end	
							table.insert(Historia_Currency_Scroll_Table,1,Historia_Currency_Table)
						end
					end	
				end
			end	
		end	
	end	
end


-------------------------------------------------------------------------------
--  Build the gold per Month table
-------------------------------------------------------------------------------
function Historia_HC_Build_PerMonth()
	row_count = 0
	Historia_Currency_Table = {}
	Historia_Currency_Scroll_Table = {}

	for i = 1, Historia_NUMBER_OF_YEARS do
		if HistoriaLocalDb.Dates[DTY[i]] then
			for j = 1, Historia_NUMBER_OF_MONTHS do
				if HistoriaLocalDb.Dates[DTY[i]][DTM[j]] then
					Historia_Currency_Table = {}
					row_count = row_count + 1
					Historia_Currency_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],"")
					amount = HistoriaLocalDb.Dates[DTY[i]][DTM[j]].Gold_Current - HistoriaLocalDb.Dates[DTY[i]][DTM[j]].Gold_Start
					if amount > 0 then 
						Historia_Currency_Table.Currency = amount
						Historia_Currency_Table.Sign = 1	
					elseif 	amount < 0 then 
						Historia_Currency_Table.Currency = amount * -1
						Historia_Currency_Table.Sign = -1	
					elseif 	amount == 0 then 
						Historia_Currency_Table.Currency = amount
						Historia_Currency_Table.Sign = 0	
					end						
					table.insert(Historia_Currency_Scroll_Table,1,Historia_Currency_Table)
				end
			end	
		end	
	end
end


-------------------------------------------------------------------------------
--  Build the gold per Year table
-------------------------------------------------------------------------------
function Historia_HC_Build_PerYear()
	row_count = 0
	Historia_Currency_Table = {}
	Historia_Currency_Scroll_Table = {}

	for i = 1, Historia_NUMBER_OF_YEARS do
		if HistoriaLocalDb.Dates[DTY[i]] then
			Historia_Currency_Table = {}
			row_count = row_count + 1
			Historia_Currency_Table.Date = DTY[i]
			amount = HistoriaLocalDb.Dates[DTY[i]].Gold_Current - HistoriaLocalDb.Dates[DTY[i]].Gold_Start
			if amount > 0 then 
				Historia_Currency_Table.Currency = amount
				Historia_Currency_Table.Sign = 1	
			elseif 	amount < 0 then 
				Historia_Currency_Table.Currency = amount * -1
				Historia_Currency_Table.Sign = -1	
			elseif 	amount == 0 then 
				Historia_Currency_Table.Currency = amount
				Historia_Currency_Table.Sign = 0	
			end						
			table.insert(Historia_Currency_Scroll_Table,1,Historia_Currency_Table)
		end	
	end
end


-------------------------------------------------------------------------------
--  Fill the Currency scroll table
--	Fill the extensions part
-------------------------------------------------------------------------------
function Historia_HC_Build_Table(id)
	if id == 1 then
		Historia_HC_Build_PerDay()
	elseif id == 2 then
		Historia_HC_Build_PerMonth()
	elseif id == 3 then	
		Historia_HC_Build_PerYear()
	end	
	
	HCSF1.scrollFrame.ScrollBar:SetValue(0)	
	HCSF1_ScrollFrameUpdate()
end	


-------------------------------------------------------------------------------
--  Currency scroll table the scrolling part.
-------------------------------------------------------------------------------
function HCSF1_ScrollFrameUpdate()
	local offset = FauxScrollFrame_GetOffset(HCSF1.scrollFrame)
	FauxScrollFrame_Update(HCSF1.scrollFrame, row_count, Historia_HC_NO_SCROLLBUTTONS, 16)

	for i = 1, Historia_HC_NO_SCROLLBUTTONS do
		local idx = offset + i
		if idx <= row_count then
			HCSF1.list[i].name1:SetText(Historia_Currency_Scroll_Table[idx].Date)
			if Historia_Currency_Scroll_Table[idx].Sign == 1 then
				HCSF1.list[i].icon1:SetTexture(cfg.CTX[2])
			elseif Historia_Currency_Scroll_Table[idx].Sign == -1 then
				HCSF1.list[i].icon1:SetTexture(cfg.CTX[3])
			elseif Historia_Currency_Scroll_Table[idx].Sign == 0 then
				HCSF1.list[i].icon1:SetTexture(cfg.CTX[4])	
			end	
			HCSF1.list[i].name2:SetText(GetCoinTextureString(Historia_Currency_Scroll_Table[idx].Currency))
			HCSF1.list[i]:Show()
		else
			HCSF1.list[i]:Hide()
		end	
	end	
end


-------------------------------------------------------------------------------
--	Create and fill the rest of the data
-------------------------------------------------------------------------------
function Historia_Currency_TheRest()
	--  Create a reference frame for the rest of the Currency info.
	local Historia_HC_J = CreateFrame("Frame","Historia_HC_J",Historia_HC)
	Historia_HC_J:SetPoint("TOPRIGHT", "Historia_HC_H", "BOTTOMRIGHT", 0, -16)
	Historia_HC_J:SetPoint("BOTTOMLEFT", "Historia_HC", "BOTTOMRIGHT", -320, 0)

	--  Create a frame for the statistics Currency text.
	local Historia_HC_JH = CreateFrame("Frame","Historia_HC_JH",Historia_HC_J)
	Historia_HC_JH:SetPoint("TOPRIGHT","Historia_HC_J",0,0)
	Historia_HC_JH:SetPoint("BOTTOMLEFT","Historia_HC_J","TOPRIGHT",-320,-24)
	Historia_HC_JH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HC_JH.F1 = Historia_HC_JH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HC_JH.F1:SetPoint("CENTER","Historia_HC_JH",0,0)
	Historia_HC_JH.F1:SetText(L["Statistics"])	

	--  Create a frame for the Best days.
	local Historia_HC_JJ = CreateFrame("Frame","Historia_HC_JJ",Historia_HC_J)
	Historia_HC_JJ:SetPoint("TOPRIGHT","Historia_HC_JH","BOTTOMRIGHT",0,-16)
	Historia_HC_JJ:SetPoint("BOTTOMLEFT","Historia_HC_JH","BOTTOMRIGHT",-320,-86)
	Historia_HC_JJ:SetBackdrop(cfg.Historia_backdrop2)

	Historia_HC_JJ.F1 = Historia_HC_JJ:CreateFontString(nil,"ARTWORK","GameFontGreen")
	Historia_HC_JJ.F1:SetPoint("Top","Historia_HC_JJ",0,-4)
	Historia_HC_JJ.F1:SetText(L["Best days"])	
	
	Historia_HC_JJ.list = {}
	for i=1,3 do
		Historia_HC_JJ.list[i] = CreateFrame("Button",nil,Historia_HC_JJ)
		Historia_HC_JJ.list[i]:SetSize(320,16)
		Historia_HC_JJ.list[i]:SetPoint("TOPRIGHT",Historia_HC_JJ,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HC_JJ.list[i]:Show()
		
		Historia_HC_JJ.list[i].name1 = Historia_HC_JJ.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HC_JJ.list[i].name1:SetSize(140,16)
		Historia_HC_JJ.list[i].name1:SetPoint("LEFT",0,0)	
		Historia_HC_JJ.list[i].name1:SetJustifyH("CENTER") 
		
		Historia_HC_JJ.list[i].icon1 = Historia_HC_JJ.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HC_JJ.list[i].icon1:SetSize(16,16)
		Historia_HC_JJ.list[i].icon1:SetPoint("LEFT", Historia_HC_JJ.list[i].name1, "RIGHT", 4, 0)		

		Historia_HC_JJ.list[i].name2 = Historia_HC_JJ.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HC_JJ.list[i].name2:SetSize(140,16)
		Historia_HC_JJ.list[i].name2:SetPoint("LEFT", Historia_HC_JJ.list[i].icon1, "RIGHT",4,0)
		Historia_HC_JJ.list[i].name2:SetJustifyH("LEFT") 
	end		
	
	--  Create a frame for the Worst days.
	local Historia_HC_JK = CreateFrame("Frame","Historia_HC_JK",Historia_HC_J)
	Historia_HC_JK:SetPoint("TOPRIGHT","Historia_HC_JJ","BOTTOMRIGHT",0,-16)
	Historia_HC_JK:SetPoint("BOTTOMLEFT","Historia_HC_JJ","BOTTOMRIGHT",-320,-86)
	Historia_HC_JK:SetBackdrop(cfg.Historia_backdrop2)

	Historia_HC_JK.F1 = Historia_HC_JK:CreateFontString(nil,"ARTWORK","GameFontRed")
	Historia_HC_JK.F1:SetPoint("Top","Historia_HC_JK",0,-4)
	Historia_HC_JK.F1:SetText(L["Worst days"])	
	
	Historia_HC_JK.list = {}
	for i=1,3 do
		Historia_HC_JK.list[i] = CreateFrame("Button",nil,Historia_HC_JK)
		Historia_HC_JK.list[i]:SetSize(320,16)
		Historia_HC_JK.list[i]:SetPoint("TOPRIGHT",Historia_HC_JK,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HC_JK.list[i]:Show()
		
		Historia_HC_JK.list[i].name1 = Historia_HC_JK.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HC_JK.list[i].name1:SetSize(140,16)
		Historia_HC_JK.list[i].name1:SetPoint("LEFT",0,0)	
		Historia_HC_JK.list[i].name1:SetJustifyH("CENTER") 
		
		Historia_HC_JK.list[i].icon1 = Historia_HC_JK.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HC_JK.list[i].icon1:SetSize(16,16)
		Historia_HC_JK.list[i].icon1:SetPoint("LEFT", Historia_HC_JK.list[i].name1, "RIGHT", 4, 0)		

		Historia_HC_JK.list[i].name2 = Historia_HC_JK.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HC_JK.list[i].name2:SetSize(140,16)
		Historia_HC_JK.list[i].name2:SetPoint("LEFT", Historia_HC_JK.list[i].icon1, "RIGHT",4,0)
		Historia_HC_JK.list[i].name2:SetJustifyH("LEFT") 
	end		
	
	--  Create a frame for the Best months.
	local Historia_HC_JL = CreateFrame("Frame","Historia_HC_JL",Historia_HC_J)
	Historia_HC_JL:SetPoint("TOPRIGHT","Historia_HC_JK","BOTTOMRIGHT",0,-16)
	Historia_HC_JL:SetPoint("BOTTOMLEFT","Historia_HC_JK","BOTTOMRIGHT",-320,-86)
	Historia_HC_JL:SetBackdrop(cfg.Historia_backdrop2)

	Historia_HC_JL.F1 = Historia_HC_JL:CreateFontString(nil,"ARTWORK","GameFontGreen")
	Historia_HC_JL.F1:SetPoint("Top","Historia_HC_JL",0,-4)
	Historia_HC_JL.F1:SetText(L["Best months"])

	Historia_HC_JL.list = {}
	for i=1,3 do
		Historia_HC_JL.list[i] = CreateFrame("Button",nil,Historia_HC_JL)
		Historia_HC_JL.list[i]:SetSize(320,16)
		Historia_HC_JL.list[i]:SetPoint("TOPRIGHT",Historia_HC_JL,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HC_JL.list[i]:Show()
		
		Historia_HC_JL.list[i].name1 = Historia_HC_JL.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HC_JL.list[i].name1:SetSize(140,16)
		Historia_HC_JL.list[i].name1:SetPoint("LEFT",0,0)	
		Historia_HC_JL.list[i].name1:SetJustifyH("CENTER") 
		
		Historia_HC_JL.list[i].icon1 = Historia_HC_JL.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HC_JL.list[i].icon1:SetSize(16,16)
		Historia_HC_JL.list[i].icon1:SetPoint("LEFT", Historia_HC_JL.list[i].name1, "RIGHT", 4, 0)		

		Historia_HC_JL.list[i].name2 = Historia_HC_JL.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HC_JL.list[i].name2:SetSize(140,16)
		Historia_HC_JL.list[i].name2:SetPoint("LEFT", Historia_HC_JL.list[i].icon1, "RIGHT",4,0)
		Historia_HC_JL.list[i].name2:SetJustifyH("LEFT") 
	end		
	
	--  Create a frame for the Worst months.
	local Historia_HC_JM = CreateFrame("Frame","Historia_HC_JM",Historia_HC_J)
	Historia_HC_JM:SetPoint("TOPRIGHT","Historia_HC_JL","BOTTOMRIGHT",0,-16)
	Historia_HC_JM:SetPoint("BOTTOMLEFT","Historia_HC_JL","BOTTOMRIGHT",-320,-86)
	Historia_HC_JM:SetBackdrop(cfg.Historia_backdrop2)
	
	Historia_HC_JM.F1 = Historia_HC_JM:CreateFontString(nil,"ARTWORK","GameFontRed")
	Historia_HC_JM.F1:SetPoint("Top","Historia_HC_JM",0,-4)
	Historia_HC_JM.F1:SetText(L["Worst months"])	
	
	Historia_HC_JM.list = {}
	for i=1,3 do
		Historia_HC_JM.list[i] = CreateFrame("Button",nil,Historia_HC_JM)
		Historia_HC_JM.list[i]:SetSize(320,16)
		Historia_HC_JM.list[i]:SetPoint("TOPRIGHT",Historia_HC_JM,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HC_JM.list[i]:Show()
		
		Historia_HC_JM.list[i].name1 = Historia_HC_JM.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HC_JM.list[i].name1:SetSize(140,16)
		Historia_HC_JM.list[i].name1:SetPoint("LEFT",0,0)	
		Historia_HC_JM.list[i].name1:SetJustifyH("CENTER") 
		
		Historia_HC_JM.list[i].icon1 = Historia_HC_JM.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HC_JM.list[i].icon1:SetSize(16,16)
		Historia_HC_JM.list[i].icon1:SetPoint("LEFT", Historia_HC_JM.list[i].name1, "RIGHT", 4, 0)		

		Historia_HC_JM.list[i].name2 = Historia_HC_JM.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HC_JM.list[i].name2:SetSize(140,16)
		Historia_HC_JM.list[i].name2:SetPoint("LEFT", Historia_HC_JM.list[i].icon1, "RIGHT",4,0)
		Historia_HC_JM.list[i].name2:SetJustifyH("LEFT") 
	end		

	--  Create a frame for the number of.
	local Historia_HC_JN = CreateFrame("Frame","Historia_HC_JN",Historia_HC_J)
	Historia_HC_JN:SetPoint("TOPRIGHT","Historia_HC_JM","BOTTOMRIGHT",0,-16)
	Historia_HC_JN:SetPoint("BOTTOMLEFT","Historia_HC_JM","BOTTOMRIGHT",-320,-50)
	Historia_HC_JN:SetBackdrop(cfg.Historia_backdrop2)
	
	Historia_HC_JN.icon1 = Historia_HC_JN:CreateTexture(nil,"ARTWORK")
	Historia_HC_JN.icon1:SetSize(16,16)
	Historia_HC_JN.icon1:SetPoint("LEFT",16,0)	
	Historia_HC_JN.icon1:SetTexture(cfg.CTX[2])	

	Historia_HC_JN.name1 = Historia_HC_JN:CreateFontString(nil,"ARTWORK","GameFontNormal")
	Historia_HC_JN.name1:SetSize(80,16)
	Historia_HC_JN.name1:SetPoint("LEFT", Historia_HC_JN.icon1,"RIGHT",4,0)
	Historia_HC_JN.name1:SetJustifyH("LEFT")
	
	Historia_HC_JN.icon2 = Historia_HC_JN:CreateTexture(nil,"ARTWORK")
	Historia_HC_JN.icon2:SetSize(16,16)
	Historia_HC_JN.icon2:SetPoint("LEFT", Historia_HC_JN.name1,"RIGHT",4,0)	
	Historia_HC_JN.icon2:SetTexture(cfg.CTX[4])	

	Historia_HC_JN.name2 = Historia_HC_JN:CreateFontString(nil,"ARTWORK","GameFontNormal")
	Historia_HC_JN.name2:SetSize(80,16)
	Historia_HC_JN.name2:SetPoint("LEFT", Historia_HC_JN.icon2,"RIGHT",4,0)
	Historia_HC_JN.name2:SetJustifyH("LEFT")	
	
	Historia_HC_JN.icon3 = Historia_HC_JN:CreateTexture(nil,"ARTWORK")
	Historia_HC_JN.icon3:SetSize(16,16)
	Historia_HC_JN.icon3:SetPoint("LEFT", Historia_HC_JN.name2,"RIGHT",4,0)	
	Historia_HC_JN.icon3:SetTexture(cfg.CTX[3])	

	Historia_HC_JN.name3 = Historia_HC_JN:CreateFontString(nil,"ARTWORK","GameFontNormal")
	Historia_HC_JN.name3:SetSize(80,16)
	Historia_HC_JN.name3:SetPoint("LEFT", Historia_HC_JN.icon3,"RIGHT",4,0)
	Historia_HC_JN.name3:SetJustifyH("LEFT")	
	
	local Historia_HC_K = CreateFrame("Frame","Historia_HC_K",Historia_HC)
	Historia_HC_K:SetPoint("TOPRIGHT","Historia_HC_J","TOPLEFT",-16,0)
	Historia_HC_K:SetPoint("BOTTOMLEFT","Historia_HC_J", "BOTTOMLEFT",-96,0)	
	Historia_HC_K:SetBackdrop(cfg.Historia_backdrop2)		
	
	Historia_HC_K.list = {}
	for i = 1,6 do
		Historia_HC_K.list[i] = CreateFrame("Button",nil,Historia_HC_K)
		Historia_HC_K.list[i]:SetSize(64,64)
		Historia_HC_K.list[i]:SetPoint("TOP",Historia_HC_K,0,(i-1)*-70-2)
		Historia_HC_K.list[i]:Show()
		
		Historia_HC_K.list[i].te1 = Historia_HC_K.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HC_K.list[i].te1:SetTexture(cfg.Icons .."challenges-bronze")		
		Historia_HC_K.list[i].te1:SetPoint("TOPLEFT",Historia_HC_K.list[i],0,0)
		Historia_HC_K.list[i].te1:SetPoint("BOTTOMRIGHT",Historia_HC_K.list[i],0,0)		
		Historia_HC_K.list[i]:Show()		
	end
end


-------------------------------------------------------------------------------
--	Determine the best/worst days
-------------------------------------------------------------------------------
function Historia_Calc_BestWorst_Days(amount,y,m,d)
	local sign 
	if amount > 0 then
		sign = 1
	elseif amount < 0 then
		sign = -1
	elseif amount == 0 then
		sign = 0
	end	
	
	if amount > Best_days[1][1] then
		Best_days[3][1] = Best_days[2][1]
		Best_days[3][2] = Best_days[2][2]
		Best_days[3][3] = Best_days[2][3]
		Best_days[3][4] = Best_days[2][4]	
		Best_days[3][5] = Best_days[2][5]			
		Best_days[2][1] = Best_days[1][1]
		Best_days[2][2] = Best_days[1][2]
		Best_days[2][3] = Best_days[1][3]
		Best_days[2][4] = Best_days[1][4]
		Best_days[2][5] = Best_days[1][5]		
		Best_days[1][1] = amount
		Best_days[1][2] = y
		Best_days[1][3] = m
		Best_days[1][4] = d	
		Best_days[1][5] = sign			
	elseif amount > Best_days[2][1] then
		Best_days[3][1] = Best_days[2][1]
		Best_days[3][2] = Best_days[2][2]
		Best_days[3][3] = Best_days[2][3]
		Best_days[3][4] = Best_days[2][4]	
		Best_days[3][5] = Best_days[2][5]			
		Best_days[2][1] = amount
		Best_days[2][2] = y
		Best_days[2][3] = m
		Best_days[2][4] = d	
		Best_days[2][5] = sign			
	elseif amount > Best_days[3][1] then
		Best_days[3][1] = amount
		Best_days[3][2] = y
		Best_days[3][3] = m
		Best_days[3][4] = d		
		Best_days[3][5] = sign	
	end	
	
	if amount <= Worst_days[1][1] then
		Worst_days[3][1] = Worst_days[2][1]
		Worst_days[3][2] = Worst_days[2][2]
		Worst_days[3][3] = Worst_days[2][3]
		Worst_days[3][4] = Worst_days[2][4]	
		Worst_days[3][5] = Worst_days[2][5]		
		Worst_days[2][1] = Worst_days[1][1]
		Worst_days[2][2] = Worst_days[1][2]
		Worst_days[2][3] = Worst_days[1][3]
		Worst_days[2][4] = Worst_days[1][4]
		Worst_days[2][5] = Worst_days[1][5]		
		Worst_days[1][1] = amount
		Worst_days[1][2] = y
		Worst_days[1][3] = m
		Worst_days[1][4] = d
		Worst_days[1][5] = sign		
	elseif amount <= Worst_days[2][1] then
		Worst_days[3][1] = Worst_days[2][1]
		Worst_days[3][2] = Worst_days[2][2]
		Worst_days[3][3] = Worst_days[2][3]
		Worst_days[3][4] = Worst_days[2][4]	
		Worst_days[3][5] = Worst_days[2][5]			
		Worst_days[2][1] = amount
		Worst_days[2][2] = y
		Worst_days[2][3] = m
		Worst_days[2][4] = d	
		Worst_days[2][5] = sign		
	elseif amount <= Worst_days[3][1] then
		Worst_days[3][1] = amount
		Worst_days[3][2] = y
		Worst_days[3][3] = m
		Worst_days[3][4] = d
		Worst_days[3][5] = sign		
	end		
end


-------------------------------------------------------------------------------
--	Determine the best/worst months
-------------------------------------------------------------------------------
function Historia_Calc_BestWorst_Months(amount,y,m)
	local sign 
	if amount > 0 then
		sign = 1
	elseif amount < 0 then
		sign = -1
	elseif amount == 0 then
		sign = 0
	end	
		
	if amount > Best_months[1][1] then
		Best_months[3][1] = Best_months[2][1]
		Best_months[3][2] = Best_months[2][2]
		Best_months[3][3] = Best_months[2][3]
		Best_months[3][4] = Best_months[2][4]			
		Best_months[2][1] = Best_months[1][1]
		Best_months[2][2] = Best_months[1][2]
		Best_months[2][3] = Best_months[1][3]
		Best_months[2][4] = Best_months[1][4]		
		Best_months[1][1] = amount
		Best_months[1][2] = y
		Best_months[1][3] = m
		Best_months[1][4] = sign			
	elseif amount > Best_months[2][1] then
		Best_months[3][1] = Best_months[2][1]
		Best_months[3][2] = Best_months[2][2]
		Best_months[3][3] = Best_months[2][3]
		Best_months[3][4] = Best_months[2][4]			
		Best_months[2][1] = amount
		Best_months[2][2] = y
		Best_months[2][3] = m
		Best_months[2][4] = sign			
	elseif amount > Best_months[3][1] then
		Best_months[3][1] = amount
		Best_months[3][2] = y
		Best_months[3][3] = m
		Best_months[3][4] = sign	
	end	
	
	if amount <= Worst_months[1][1] then
		Worst_months[3][1] = Worst_months[2][1]
		Worst_months[3][2] = Worst_months[2][2]
		Worst_months[3][3] = Worst_months[2][3]
		Worst_months[3][4] = Worst_months[2][4]		
		Worst_months[2][1] = Worst_months[1][1]
		Worst_months[2][2] = Worst_months[1][2]
		Worst_months[2][3] = Worst_months[1][3]
		Worst_months[2][4] = Worst_months[1][4]		
		Worst_months[1][1] = amount
		Worst_months[1][2] = y
		Worst_months[1][3] = m
		Worst_months[1][4] = sign		
	elseif amount <= Worst_months[2][1] then
		Worst_months[3][1] = Worst_months[2][1]
		Worst_months[3][2] = Worst_months[2][2]
		Worst_months[3][3] = Worst_months[2][3]
		Worst_months[3][4] = Worst_months[2][4]			
		Worst_months[2][1] = amount
		Worst_months[2][2] = y
		Worst_months[2][3] = m
		Worst_months[2][4] = sign		
	elseif amount <= Worst_months[3][1] then
		Worst_months[3][1] = amount
		Worst_months[3][2] = y
		Worst_months[3][3] = m
		Worst_months[3][4] = sign		
	end		
end


-------------------------------------------------------------------------------
--	Fill the rest of the currency Tab
-------------------------------------------------------------------------------
function Handle_Currency_TheRest()
	local count_pos = 0
	local count_neg = 0
	local count_zero = 0
	
	for i = 1, 3 do
		for j = 1, 5 do
			Best_days[i][j] = -999999999
			Worst_days[i][j] = 999999999
			Best_months[i][j] = -999999999
			Worst_months[i][j] = 999999999
		end
	end	

	for i = 1, Historia_NUMBER_OF_YEARS do
		if HistoriaLocalDb.Dates[DTY[i]] then
			for j = 1, Historia_NUMBER_OF_MONTHS do
				if HistoriaLocalDb.Dates[DTY[i]][DTM[j]] then
					amount = HistoriaLocalDb.Dates[DTY[i]][DTM[j]].Gold_Current - HistoriaLocalDb.Dates[DTY[i]][DTM[j]].Gold_Start
					-- Function takes 3 aguments, amount,year,month
					Historia_Calc_BestWorst_Months(amount,DTY[i],DTM[j])
					for k = 1, Historia_NUMBER_OF_DAYS do
						if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]] then				
							amount = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Current - HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Start
							-- Function takes 4 aguments, amount,year,month, day
							Historia_Calc_BestWorst_Days(amount,DTY[i],DTM[j],DTD[k])
							
							if amount > 0 then 
								count_pos = count_pos + 1	
							elseif 	amount < 0 then 
								count_neg = count_neg + 1
							elseif 	amount == 0 then 
								count_zero = count_zero + 1	
							end	
						end
					end	
				end
			end	
		end	
	end	

	-- Make sure all amounts (money) are positive. Otherwise GetCoinTextureString will throw an error
	for i =1, 3 do
		if Best_days[i][1] < 0 then
			Best_days[i][1] = Best_days[i][1] * -1
		end	
		if Worst_days[i][1] < 0 then
			Worst_days[i][1] = Worst_days[i][1] * -1
		end	
		if Best_months[i][1] < 0 then
			Best_months[i][1] = Best_months[i][1] * -1
		end	
		if Worst_months[i][1] < 0 then
			Worst_months[i][1] = Worst_months[i][1] * -1
		end	
	end	
	
	for i =1, 3 do	
		if Best_days[i][1] ~= 999999999 then
			Historia_HC_JJ.list[i].name1:SetText(GetCoinTextureString(Best_days[i][1]))
			Historia_HC_JJ.list[i].name2:SetText(cfg.Historia_FormatDate(Best_days[i][2],Best_days[i][3],Best_days[i][4]))
			if Best_days[i][5] == 1 then
				Historia_HC_JJ.list[i].icon1:SetTexture(cfg.CTX[2])
			elseif Best_days[i][5] == -1 then
				Historia_HC_JJ.list[i].icon1:SetTexture(cfg.CTX[3])
			elseif Best_days[i][5] == 0 then
				Historia_HC_JJ.list[i].icon1:SetTexture(cfg.CTX[4])	
			end
		end	
	end
	
	for i =1, 3 do	
		if Worst_days[i][1] ~= 999999999 then
			Historia_HC_JK.list[i].name1:SetText(GetCoinTextureString(Worst_days[i][1]))
			Historia_HC_JK.list[i].name2:SetText(cfg.Historia_FormatDate(Worst_days[i][2],Worst_days[i][3],Worst_days[i][4]))
			if Worst_days[i][5] == 1 then
				Historia_HC_JK.list[i].icon1:SetTexture(cfg.CTX[2])
			elseif Worst_days[i][5] == -1 then
				Historia_HC_JK.list[i].icon1:SetTexture(cfg.CTX[3])
			elseif Worst_days[i][5] == 0 then
				Historia_HC_JK.list[i].icon1:SetTexture(cfg.CTX[4])	
			end
		end	
	end	
	
	for i =1, 3 do	
		if Best_months[i][1] ~= 999999999 then
			Historia_HC_JL.list[i].name1:SetText(GetCoinTextureString(Best_months[i][1]))
			Historia_HC_JL.list[i].name2:SetText(cfg.Historia_FormatDate(Best_months[i][2],Best_months[i][3],""))
			if Best_months[i][4] == 1 then
				Historia_HC_JL.list[i].icon1:SetTexture(cfg.CTX[2])
			elseif Best_months[i][4] == -1 then
				Historia_HC_JL.list[i].icon1:SetTexture(cfg.CTX[3])
			elseif Best_months[i][4] == 0 then
				Historia_HC_JL.list[i].icon1:SetTexture(cfg.CTX[4])	
			end
		end	
	end
	
	for i =1, 3 do	
		if Worst_months[i][1] ~= 999999999 then
			Historia_HC_JM.list[i].name1:SetText(GetCoinTextureString(Worst_months[i][1]))
			Historia_HC_JM.list[i].name2:SetText(cfg.Historia_FormatDate(Worst_months[i][2],Worst_months[i][3],""))
			if Worst_months[i][4] == 1 then
				Historia_HC_JM.list[i].icon1:SetTexture(cfg.CTX[2])
			elseif Worst_months[i][4] == -1 then
				Historia_HC_JM.list[i].icon1:SetTexture(cfg.CTX[3])
			elseif Worst_months[i][4] == 0 then
				Historia_HC_JM.list[i].icon1:SetTexture(cfg.CTX[4])	
			end
		end	
	end
	
	Historia_HC_JN.name1:SetText(count_pos)
	Historia_HC_JN.name2:SetText(count_zero)
	Historia_HC_JN.name3:SetText(count_neg)	
end


-------------------------------------------------------------------------------
--  Handle the Currency Tab
-------------------------------------------------------------------------------
function Historia_HC_Update()
	Historia_HC_Build_Table(1)
	Handle_Currency_TheRest()
end
