--[[	*** Historia ***
Written by : Yukyuk, EU-Moonglade
--]]

-------------------------------------------------------------------------------
--  From _Global to local.
-------------------------------------------------------------------------------
local _G = _G

-------------------------------------------------------------------------------
--  AddOn namespace.
-------------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local cfg = private.cfg
local addon = cfg.addon_name


-------------------------------------------------------------------------------
--  Libstubs.
-------------------------------------------------------------------------------
local L 		= LibStub("AceLocale-3.0"):GetLocale("Historia")
local LibQTip 	= LibStub:GetLibrary("LibQTip-1.0")


-------------------------------------------------------------------------------
--	Local variables
-------------------------------------------------------------------------------
local row_count = 0
local Historia_HL_NO_SCROLLBUTTONS = 24		--  number of selection buttons for the levels frame
local Historia_Levels_Table = {}
local Historia_Levels_Scroll_Table = {}	


--------------------------------------------------------------------------------
--  This is the Historia level frame
--------------------------------------------------------------------------------	
function Historia_Level()
	local Historia_HL = CreateFrame("Frame","Historia_HL",Historia_UI)
	Historia_HL:SetPoint("TOP", "Historia_UI", 0, -16)
	Historia_HL:SetPoint("BOTTOM", "Historia_UI", 0, 16)
	Historia_HL:SetPoint("LEFT", "Historia_UI", 16, 0)
	Historia_HL:SetPoint("RIGHT", "Historia_UI", -16, 0)
	Historia_HL:SetBackdrop(cfg.Historia_backdrop3)
	
	--  Create a frame for the header level info.
	local Historia_HL_H = CreateFrame("Frame","Historia_HL_H",Historia_HL)
	Historia_HL_H:SetPoint("TOPLEFT","Historia_HL",0,0)
	Historia_HL_H:SetPoint("BOTTOMRIGHT","Historia_HL","TOPRIGHT",0,-48)
	Historia_HL_H:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HL_H.F1 = Historia_HL_H:CreateFontString(nil,"ARTWORK","GameFontNormalHuge")
	Historia_HL_H.F1:SetPoint("CENTER","Historia_HL_H",0,0)
	Historia_HL_H.F1:SetText(L["History of:"] .. " " .. L["Levels"])
	
	Historia_Level_Scrollframe()
	Historia_Level_TheRest()	

	Historia_HL:Hide()
end	


-------------------------------------------------------------------------------
--  Fill the Level scroll table
-------------------------------------------------------------------------------
function Historia_Level_Scrollframe()
	--  Create a reference frame for the rest of the level info.
	local Historia_HL_I = CreateFrame("Frame","Historia_HL_I",Historia_HL)
	Historia_HL_I:SetPoint("TOPLEFT", "Historia_HL_H", "BOTTOMLEFT", 0, -16)
	Historia_HL_I:SetPoint("BOTTOMRIGHT", "Historia_HL", "BOTTOMRIGHT", 0, 0)
	local Historia_HL_I_Width = Historia_HL_I:GetWidth()	
	local Historia_HL_I_Height = Historia_HL_I:GetHeight()

	--  Create a frame for the header level text.
	local Historia_HL_IH = CreateFrame("Frame","Historia_HL_IH",Historia_HL_I)
	Historia_HL_IH:SetPoint("TOPLEFT","Historia_HL_I",0,0)
	Historia_HL_IH:SetPoint("BOTTOMRIGHT","Historia_HL_I","TOPLEFT",320,-24)
	Historia_HL_IH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HL_IH.F1 = Historia_HL_IH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HL_IH.F1:SetPoint("CENTER","Historia_HL_IH",0,0)
	Historia_HL_IH.F1:SetText(L["Levels"])	
	
	--  Create the container for the levels scroll frame.
	local HLSF1 = CreateFrame("Frame","HLSF1",Historia_HL_I)
	HLSF1:SetPoint("TOPLEFT", "Historia_HL_I", "TOPLEFT", 0, -24)
	HLSF1:SetPoint("BOTTOMRIGHT", "Historia_HL_I", "TOPLEFT", 320, Historia_HL_I_Height*-1)
	HLSF1:SetBackdrop((cfg.Historia_backdrop2))

	--  Create the container for the levels scroll bar.
	local HLSF1_bar = CreateFrame("Frame","HLSF1_bar",HLSF1)
	HLSF1_bar:SetPoint("TOPRIGHT", "HLSF1", 0, 0)
	HLSF1_bar:SetPoint("BOTTOMLEFT", "HLSF1", "BOTTOMRIGHT", -24, 0)
	HLSF1_bar:SetBackdrop(cfg.Historia_backdrop2)	

	--  Create the list of buttons that go into the levels scroll frame
	HLSF1.list = {}
	for i=1,Historia_HL_NO_SCROLLBUTTONS do
		HLSF1.list[i] = CreateFrame("Button",nil,HLSF1)
		HLSF1.list[i]:SetSize(320,16)
		HLSF1.list[i]:SetPoint("TOPLEFT",HLSF1,"TOPLEFT",8,(i-1)*-16-4)
		HLSF1.list[i]:Show()
		
		HLSF1.list[i].name1 = HLSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		HLSF1.list[i].name1:SetSize(160,16)
		HLSF1.list[i].name1:SetPoint("LEFT",0,0)
		HLSF1.list[i].name1:SetJustifyH("LEFT") 

		HLSF1.list[i].name2 = HLSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		HLSF1.list[i].name2:SetSize(160,16)
		HLSF1.list[i].name2:SetPoint("LEFT", HLSF1.list[i].name1, "RIGHT",4,0)
		HLSF1.list[i].name2:SetJustifyH("LEFT") 
	end	
	
	-- 	Create the scroll frame
	HLSF1.scrollFrame = CreateFrame("ScrollFrame","HLSF1_scrollFrame",HLSF1,"FauxScrollFrameTemplate")
	HLSF1.scrollFrame:SetPoint("TOPLEFT",HLSF1,"TOPLEFT",0,-2)
	HLSF1.scrollFrame:SetPoint("BOTTOMRIGHT",HLSF1,"BOTTOMRIGHT",-26,2)
	HLSF1.scrollFrame:SetScript("OnVerticalScroll",function(self,offset)
	FauxScrollFrame_OnVerticalScroll(self,offset,16,HLSF1_ScrollFrameUpdate)
	end)	
end 


-------------------------------------------------------------------------------
--  Fill the Level scroll table
-------------------------------------------------------------------------------
function Historia_HL_Build_Table()
	row_count = 0
	Historia_Level_Table = {}
	Historia_Level_Scroll_Table = {}	

	for idx = 1, #HistoriaLocalDb.Level do
		Historia_Level_Table = {}
		row_count = row_count + 1
		
		Historia_Level_Table.Level		= HistoriaLocalDb.Level[idx].level
		Historia_Level_Table.Time		= HistoriaLocalDb.Level[idx].time
		tinsert(Historia_Level_Scroll_Table,1,Historia_Level_Table)
	end	
	
	for i=1,cfg.Historia_HIL1_Buttons do
		if HistoriaLocalDb.Level[cfg.Historia_HIL1_Text[i]] then
			Historia_HL_JJ[i].name2:SetText("")
			Historia_HL_JJ[i].name2:SetText(format(date("%a, %b %d %Y %H:%M",HistoriaLocalDb.Level[cfg.Historia_HIL1_Text[i]].time)))
		end
	end	
end	


-------------------------------------------------------------------------------
--  Level scroll table the scrolling part.
-------------------------------------------------------------------------------
function HLSF1_ScrollFrameUpdate()
	local offset = FauxScrollFrame_GetOffset(HLSF1.scrollFrame)
	FauxScrollFrame_Update(HLSF1.scrollFrame, row_count, Historia_HL_NO_SCROLLBUTTONS, 16)

	for i = 1, Historia_HL_NO_SCROLLBUTTONS do
		local idx = offset + i
		if idx <= row_count then
			HLSF1.list[i].name1:SetText(format(date("%a, %b %d %Y %H:%M", Historia_Level_Scroll_Table[idx].Time)))
			HLSF1.list[i].name2:SetText(Historia_Level_Scroll_Table[idx].Level)
			HLSF1.list[i]:Show()
		else
			HLSF1.list[i]:Hide()
		end	
	end	
end


-------------------------------------------------------------------------------
--	Create the rest of the Levels frame
-------------------------------------------------------------------------------
function Historia_Level_TheRest()
	--  Create a reference frame for the rest of the Levels info.
	local Historia_HL_J = CreateFrame("Frame","Historia_HL_J",Historia_HL)
	Historia_HL_J:SetPoint("TOPRIGHT", "Historia_HL_H", "BOTTOMRIGHT", 0, -16)
	Historia_HL_J:SetPoint("BOTTOMLEFT", "Historia_HL", "BOTTOMRIGHT", -320, 0)	
	--Historia_HL_J:SetBackdrop(cfg.Historia_backdrop2)	

	local Historia_HL_JH = CreateFrame("Frame","Historia_HL_JH",Historia_HL_J)
	Historia_HL_JH:SetPoint("TOPLEFT","Historia_HL_J",0,0)
	Historia_HL_JH:SetPoint("BOTTOMRIGHT","Historia_HL_J","TOPRIGHT",0,-24)
	Historia_HL_JH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HL_JH.F1 = Historia_HL_JH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HL_JH.F1:SetPoint("CENTER","Historia_HL_JH",0,0)
	Historia_HL_JH.F1:SetText(L["Statistics"])	
	
	local Historia_HL_JJ = CreateFrame("Frame","Historia_HL_JJ",Historia_HL_J)
	Historia_HL_JJ:SetPoint("TOPLEFT","Historia_HL_JH","BOTTOMLEFT",0,0)
	Historia_HL_JJ:SetPoint("BOTTOMRIGHT","Historia_HL_J",0,-0)
	--Historia_HL_JJ:SetBackdrop(cfg.Historia_backdrop2)	

	Historia_HL_JJ.list = {}
	for i=1,cfg.Historia_HIL1_Buttons do
		Historia_HL_JJ[i] = CreateFrame("Button",nil,Historia_HL_JJ)
		Historia_HL_JJ[i]:SetSize(64,32)
		Historia_HL_JJ[i]:SetPoint("TOPLEFT",Historia_HL_JJ,"TOPLEFT",0,(i-1)*-32-4)
		Historia_HL_JJ[i]:SetBackdrop(cfg.Historia_backdrop2)
		Historia_HL_JJ[i]:Show()
		
		Historia_HL_JJ[i].name1 = Historia_HL_JJ[i]:CreateFontString(nil,"ARTWORK","GameFontNormalHuge")
		Historia_HL_JJ[i].name1:SetSize(64,32)
		Historia_HL_JJ[i].name1:SetPoint("CENTER",0,0)	
		Historia_HL_JJ[i].name1:SetText(cfg.colors["Copper"] .. cfg.Historia_HIL1_Text[i] .. cfg.colors["End"])		

		Historia_HL_JJ[i] = CreateFrame("Button",nil,Historia_HL_JJ)
		Historia_HL_JJ[i]:SetSize(256,32)
		Historia_HL_JJ[i]:SetPoint("TOPLEFT",Historia_HL_JJ,"TOPLEFT",64,(i-1)*-32-4)
		Historia_HL_JJ[i]:SetBackdrop(cfg.Historia_backdrop2)
		Historia_HL_JJ[i]:Show()

		Historia_HL_JJ[i].name2 = Historia_HL_JJ[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HL_JJ[i].name2:SetSize(160,32)
		Historia_HL_JJ[i].name2:SetPoint("LEFT",8,0)	
		Historia_HL_JJ[i].name2:SetJustifyH("LEFT")	
		Historia_HL_JJ[i].name2:SetText(L["Not recorded"])		
	end	
	
	local Historia_HL_K = CreateFrame("Frame","Historia_HL_K",Historia_HL)
	Historia_HL_K:SetPoint("TOPRIGHT","Historia_HL_J","TOPLEFT",-16,0)
	Historia_HL_K:SetPoint("BOTTOMLEFT","Historia_HL_J", "BOTTOMLEFT",-96,0)	
	Historia_HL_K:SetBackdrop(cfg.Historia_backdrop2)		
	
	Historia_HL_K.list = {}
	for i = 1,6 do
		Historia_HL_K.list[i] = CreateFrame("Button",nil,Historia_HL_K)
		Historia_HL_K.list[i]:SetSize(64,64)
		Historia_HL_K.list[i]:SetPoint("TOP",Historia_HL_K,0,(i-1)*-70-2)
		Historia_HL_K.list[i]:Show()
		
		Historia_HL_K.list[i].te1 = Historia_HL_K.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HL_K.list[i].te1:SetTexture(cfg.Icons .."challenges-copper")		
		Historia_HL_K.list[i].te1:SetPoint("TOPLEFT",Historia_HL_K.list[i],0,0)
		Historia_HL_K.list[i].te1:SetPoint("BOTTOMRIGHT",Historia_HL_K.list[i],0,0)		
		Historia_HL_K.list[i]:Show()		
	end	
end

-------------------------------------------------------------------------------
--  Handle the Levels Tab
-------------------------------------------------------------------------------
function Historia_HL_Update()
	Historia_HL_Build_Table()
	
	HLSF1.scrollFrame.ScrollBar:SetValue(0)	
	HLSF1_ScrollFrameUpdate()	
end
