--[[	*** Historia ***
Written by : Yukyuk, EU-Moonglade
--]]

-------------------------------------------------------------------------------
--  From _Global to local.
-------------------------------------------------------------------------------
local _G = _G
local tinsert, tremove, tsort, twipe = _G.table.insert, _G.table.remove, _G.table.sort, _G.table.wipe


-------------------------------------------------------------------------------
--  AddOn name space.
-------------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local cfg = private.cfg
local addon = cfg.addon_name


-------------------------------------------------------------------------------
--  Libstubs.
-------------------------------------------------------------------------------
local L 		= LibStub("AceLocale-3.0"):GetLocale("Historia")
local LDB		= LibStub("LibDataBroker-1.1")
local LDBIcon 	= LibStub("LibDBIcon-1.0")
local LibQTip 	= LibStub:GetLibrary("LibQTip-1.0")


--  Define the tables for the player professions
local Historia_Professions_init = {}	--	This table holds the initial professions and their levels.
										--	Filled when the players enters the world
local Historia_Professions_current = {}	--  This table holds the current professions and their levels.
										--	We compare this table to the init table so we can detect what has changed.


-------------------------------------------------------------------------------
--  Local functions.
-------------------------------------------------------------------------------
--  Function to split a string into two parts.
-------------------------------------------------------------------------------
local function splitName(splitter,name)
	local part1, part2
	part1, part2 = strsplit(splitter, name, 2)
	return part1, part2
end


-------------------------------------------------------------------------------
--  Check the need to define initial content of dates table.
--  For example: when we pass midnight while playing.
-------------------------------------------------------------------------------
local function HRrecorder_Check_Dates()
	cfg.ADDON_YS = date("%Y")
	cfg.ADDON_MS = date("%m")
	cfg.ADDON_DS = date("%d")

	if not HistoriaLocalDb.Dates or HistoriaLocalDb.Dates[cfg.ADDON_YS] == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS] = {}
		HistoriaLocalDb.Dates[cfg.ADDON_YS].Gold_Start = GetMoney()
		HistoriaLocalDb.Dates[cfg.ADDON_YS].Gold_Current = GetMoney()
	end

	if HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS] == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS] = {}
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS].Gold_Start = GetMoney()
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS].Gold_Current = GetMoney()
	end

	if HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS] == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS] = {}
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Gold_Start = GetMoney()
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Gold_Current = GetMoney()
	end

	if HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Level == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Level = 0
	end

	if HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Professions == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Professions = 0
	end
	
	if HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Skills == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Skills = 0
	end	

	if HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Quests == nil then
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Quests = 0
	end
end


-------------------------------------------------------------------------------
--  Initialize database
-------------------------------------------------------------------------------
function Historia_Database()
	-- This part is the database (Global) for all characters
	if HistoriaGlobalDb == nil then
		HistoriaGlobalDb = {}
	end

	if not HistoriaGlobalDb.UI then
		HistoriaGlobalDb.UI = {
			point = "CENTER",
			relativePoint = "CENTER",
			pos = {
				X = 0,
				Y = 0,
			},
		}
	end
	
	if not HistoriaGlobalDb.OPTIONS then
		HistoriaGlobalDb.OPTIONS = {Minimap = true}
	end	

	if not HistoriaGlobalDb[cfg.REALM_NAME] then
		HistoriaGlobalDb[cfg.REALM_NAME] = {}
	end

	if not HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME] then
		HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME] = {}
	end

	if not HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL then
		HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL = {}
	end

	if not HistoriaGlobalDb.Database_build then
		HistoriaGlobalDb.Version = 1
		HistoriaGlobalDb.Database_build = time()
		HistoriaGlobalDb.Enter_count = 0
		HistoriaGlobalDb.Leave_time = 0
		HistoriaGlobalDb.Leave_count = 0
		HistoriaGlobalDb.minimapShow = true
	end

	-- This part is the database (Local) for each character
	if HistoriaLocalDb == nil then
		HistoriaLocalDb = {}
	end

	if not HistoriaLocalDb.Database_build then
		HistoriaLocalDb.Version = 1
		HistoriaLocalDb.Enter_count = 0
		HistoriaLocalDb.Database_build = time()
		HistoriaLocalDb.Leave_time = 0
		HistoriaLocalDb.Leave_count = 0
		HistoriaLocalDb.Gold_Current = GetMoney()
		HistoriaLocalDb.Gold_Start = GetMoney()
	end

	--  Create the Dates table
	if not HistoriaLocalDb.Dates then
		HistoriaLocalDb.Dates = {}
	end
	--  Check if the date is present
	HRrecorder_Check_Dates()

	if not HistoriaLocalDb.Level then
		HistoriaLocalDb.Level = {}
		--  New character, insert character level in the level table
		local plr = {}
		plr.time = time()
		plr.level = UnitLevel("player")
		table.insert(HistoriaLocalDb.Level, plr)
		--  New character, insert new character level in the dates table
		HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Level =
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Level + 1
	end

	if not HistoriaLocalDb.Professions then
		HistoriaLocalDb.Professions = {}
	end
	
	if not HistoriaLocalDb.Skills then
		HistoriaLocalDb.Skills = {}
	end

	if not HistoriaLocalDb.Quests then
		HistoriaLocalDb.Quests = {}
	end
end


-------------------------------------------------------------------------------
--	Handle the Lib Data Broker OnClick event.
-------------------------------------------------------------------------------
function Historia_LDB_OnClick(frame, button)
	if button == "LeftButton" then
		Historia_Toggle_UI()
	end
end


-------------------------------------------------------------------------------
--	Create the Lib Data Broker
-------------------------------------------------------------------------------
function Historia_Create_LDB()
	Historia_LDB = LDB:NewDataObject("Historia", {
			type = "data source",
			text = "Historia",
			icon = [[Interface\Addons\HistoriaClassic\Icons\HistoriaPurple]],
			OnClick = Historia_LDB_OnClick,
		})

	if not HistoriaLDBIconDB then HistoriaLDBIconDB = {} end
	if HistoriaGlobalDb.OPTIONS.Minimap then
		LDBIcon:Register("HistoriaIcon", Historia_LDB, HistoriaLDBIconDB)
	end	
end


-------------------------------------------------------------------------------
--	Extract the data from the CHAT_MSG_SKILL line
-------------------------------------------------------------------------------
local function Historia_Match_rank(line)
	local a = string.match(line,"%d+")
	if a ~= nil then
		return(a) 
	end	
	return(0)
end

local Two_Handers = {
	[1] = 	{[1] = L["Axes"],	[2] = 132395,[3] = false},
	[2] = 	{[1] = L["Maces"],	[2] = 133479,[3] = false},
	[3] = 	{[1] = L["Swords"],	[2] = 132223,[3] = false},	
	}
local function Historia_Find_name(line)
	--	First check for two handed weapon ability skill gains
	for i = 1, #cfg.WTX do
		local a, b = string.find(line,L["Two"])
		if a ~= nil then
			for j = 1, #Two_Handers do
				local c, d = string.find(line,Two_Handers[j][1])
				if c ~= nil then
					if j == 1 then 
						return cfg.WTX[2][1],1 
					elseif j == 2 then	
						return cfg.WTX[3][1],1 	
					else
						return cfg.WTX[4][1],1 	
					end	
				end	
			end
		end	
	end

	--	Second check for other weapon ability skill gains
	for i = 1, #cfg.WTX do
		local a, b = string.find(line,cfg.WTX[i][1])
		if a ~= nil then
			return cfg.WTX[i][1],1 
		end	
	end
	--	Third check for profession skill gains
	for i = 1, #cfg.PTX do
		local c, d = string.find(line,cfg.PTX[i][1])
		if c ~= nil then
			return cfg.PTX[i][1],2
		end	
	end	
	--	Fourth check for talent skill gains
	for i = 1, #cfg.TTX do
		local e, f = string.find(line,cfg.TTX[i][1])
		if e ~= nil then
			return cfg.TTX[i][1],3
		end	
	end		
	return "Error"
end

-------------------------------------------------------------------------------
--	Store the professions info in the database
-------------------------------------------------------------------------------
function Historia_professions_database()
	local DB_name
	local DB_rank
	local DB_kind

	cfg.PLAYER_LEVEL 	= _G.UnitLevel("player")	--	Get the current Player level

	if #HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL == 0 then
		return	
	end
	
	for i = 1, #HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL do
		DB_name, DB_kind = Historia_Find_name(HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL[i])
		if DB_name == "Error" then
			--print("Historia Error: ", HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL[i])
			return
		end
		
		--	When no rank is found, for Weapon skills and professions set to 1,
		--	For Talents set to 5 * Player level
		DB_rank	= Historia_Match_rank(HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL[i])
		if DB_rank == 0 then
			if DB_kind == 1 or DB_kind == 2 then
				DB_rank = 1
			else
				DB_rank = cfg.PLAYER_LEVEL * 5
			end
		end	

		local ppr = {}
		ppr.time = time()
		ppr.name = DB_name
		ppr.rank = DB_rank	
		ppr.kind = DB_kind
		if DB_kind == 1 or DB_kind == 3 then
			table.insert(HistoriaLocalDb.Skills, ppr)
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Skills = 
				HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Skills + 1
		else	
			table.insert(HistoriaLocalDb.Professions, ppr)
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Professions = 
				HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Professions + 1
		end	
	end	

	HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL = {}
end


-------------------------------------------------------------------------------
--	Handle the CHAT_MSG_SKILL event
-------------------------------------------------------------------------------
local function Historia_Handle_CHATMSGSKILL(self,event,msg)
	table.insert(HistoriaGlobalDb[cfg.REALM_NAME][cfg.PLAYER_NAME].CHATMSGSKILL,1,msg)
end


-------------------------------------------------------------------------------
--	Create and handle the event frame
-------------------------------------------------------------------------------
	local Historia_event_frame = CreateFrame("Frame")
	ChatFrame_AddMessageEventFilter("CHAT_MSG_SKILL",Historia_Handle_CHATMSGSKILL)
	Historia_event_frame:RegisterEvent("PLAYER_ENTERING_WORLD")
	Historia_event_frame:RegisterEvent("PLAYER_LEAVING_WORLD")
	Historia_event_frame:RegisterEvent("PLAYER_LEVEL_UP")
	Historia_event_frame:RegisterEvent("PLAYER_MONEY")
	Historia_event_frame:RegisterEvent("QUEST_TURNED_IN")

	Historia_event_frame:SetScript("OnEvent", function(self, event, arg1, arg2)
		if event == "PLAYER_ENTERING_WORLD" then
			Historia_Database()
			Historia_Create_LDB()
			--  Set the leave count for the global/local database up by 1
			HistoriaGlobalDb.Enter_count = HistoriaGlobalDb.Enter_count + 1
			HistoriaLocalDb.Enter_count = HistoriaLocalDb.Enter_count + 1
			Historia_Create_UI()
			--	This event, SKILL_LINES_CHANGED fires too soon for Historia, thus register here.
			Historia_event_frame:RegisterEvent("SKILL_LINES_CHANGED")
		elseif event == "PLAYER_LEAVING_WORLD" then
			--  Set the leave count for the global/local database up by 1
			HistoriaGlobalDb.Leave_count = HistoriaGlobalDb.Leave_count + 1
			HistoriaLocalDb.Leave_count = HistoriaLocalDb.Leave_count + 1
			--  This is the time stamp of the last player leaving Historia.
			HistoriaGlobalDb.Leave_time = time()
			--  This is the time stamp of the last time a player left Historia.
			HistoriaLocalDb.Leave_time = time()
		elseif event == "PLAYER_LEVEL_UP" then
			HRrecorder_Check_Dates()
			local plr = {}
			plr.time = time()
			plr.level = arg1
			--  Insert new player level in the level table
			table.insert(HistoriaLocalDb.Level, plr)
			--  Insert new player level in the dates table
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Level = 
				HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Level + 1
		elseif event == "PLAYER_MONEY" then
			HRrecorder_Check_Dates()
			HistoriaLocalDb.Gold_Current = GetMoney()
			HistoriaLocalDb.Dates[cfg.ADDON_YS].Gold_Current = GetMoney()
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS].Gold_Current = GetMoney()
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Gold_Current = GetMoney()
		elseif event == "QUEST_TURNED_IN" then
			HRrecorder_Check_Dates()
			local Historia_QuestId = arg1
			local HistoriaQuestText = C_QuestLog.GetQuestInfo(Historia_QuestId)
			local pqr1 = {}
			pqr1.time = time()
			pqr1.Complete_questText = HistoriaQuestText	-- QuestId is stored twice
			pqr1.Complete_questID = Historia_QuestId
			table.insert(HistoriaLocalDb.Quests, pqr1)
			HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Quests = 
				HistoriaLocalDb.Dates[cfg.ADDON_YS][cfg.ADDON_MS][cfg.ADDON_DS].Quests + 1
		elseif event == "SKILL_LINES_CHANGED" then
			HRrecorder_Check_Dates()
			Historia_professions_database()
		end
	end)

