--[[	*** Historia ***
Written by : Yukyuk, EU-Moonglade
--]]

-------------------------------------------------------------------------------
--  From _Global to local.
-------------------------------------------------------------------------------
local _G = _G


-------------------------------------------------------------------------------
--  AddOn namespace.
-------------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local cfg = private.cfg
local addon = cfg.addon_name


-------------------------------------------------------------------------------
--  Libstubs.
-------------------------------------------------------------------------------
local L 		= LibStub("AceLocale-3.0"):GetLocale("Historia")
local LibQTip 	= LibStub:GetLibrary("LibQTip-1.0")


-------------------------------------------------------------------------------
--	Local constants
-------------------------------------------------------------------------------
local row_count = 0
local Historia_HQ_NO_SCROLLBUTTONS = 24		--  number of scroll buttons for the Quests frame
local Historia_Quests_Tab = {}				--	this variable holds the selection buttons
local Historia_Quests_Table = {}			--	this varaible holds the Quests dates selected from the database
local Historia_Quests_Scroll_Table = {}		--	this variable holds the selected lines that go into the scroll table


--------------------------------------------------------------------------------
--  This is the Historia quests frame
--------------------------------------------------------------------------------	
function Historia_Quests()
	local Historia_HQ = CreateFrame("Frame","Historia_HQ",Historia_UI)
	Historia_HQ:SetID(1)
	Historia_HQ:SetPoint("TOP", "Historia_UI", 0, -16)
	Historia_HQ:SetPoint("BOTTOM", "Historia_UI", 0, 16)
	Historia_HQ:SetPoint("LEFT", "Historia_UI", 16, 0)
	Historia_HQ:SetPoint("RIGHT", "Historia_UI", -16, 0)
	Historia_HQ:SetBackdrop(cfg.Historia_backdrop3)
	
	--  Create a frame for the header Quests info.
	local Historia_HQ_H = CreateFrame("Frame","Historia_HQ_H",Historia_HQ)
	Historia_HQ_H:SetPoint("TOPLEFT","Historia_HQ",0,0)
	Historia_HQ_H:SetPoint("BOTTOMRIGHT","Historia_HQ","TOPRIGHT",0,-48)
	Historia_HQ_H:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HQ_H.F1 = Historia_HQ_H:CreateFontString(nil,"ARTWORK","GameFontNormalHuge")
	Historia_HQ_H.F1:SetPoint("CENTER","Historia_HQ_H",0,0)
	Historia_HQ_H.F1:SetText(L["History of:"] .. " " .. QUESTS_LABEL)	
	
	Historia_Quests_Scrollframe()
	Historia_Quests_TheRest()	

	Historia_HQ:Hide()
end	


-------------------------------------------------------------------------------
--  Fill the Quests scroll table
-------------------------------------------------------------------------------
function Historia_Quests_Scrollframe()
	--  Create a reference frame for the rest of the Quests info.
	local Historia_HQ_I = CreateFrame("Frame","Historia_HQ_I",Historia_HQ)
	Historia_HQ_I:SetPoint("TOPLEFT", "Historia_HQ_H", "BOTTOMLEFT", 0, -16)
	Historia_HQ_I:SetPoint("BOTTOMRIGHT", "Historia_HQ", "BOTTOMRIGHT", 0, 0)
	local Historia_HQ_I_Width = Historia_HQ_I:GetWidth()	
	local Historia_HQ_I_Height = Historia_HQ_I:GetHeight()

	--  Create a frame for the header Quests text.
	local Historia_HQ_IH = CreateFrame("Frame","Historia_HQ_IH",Historia_HQ_I)
	Historia_HQ_IH:SetPoint("TOPLEFT","Historia_HQ_I",0,0)
	Historia_HQ_IH:SetPoint("BOTTOMRIGHT","Historia_HQ_I","TOPLEFT",540,-24)
	Historia_HQ_IH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HQ_IH.F1 = Historia_HQ_IH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HQ_IH.F1:SetPoint("CENTER","Historia_HQ_IH",0,0)
	Historia_HQ_IH.F1:SetText(QUESTS_LABEL)	
	
	--  Create the container for the Quests scroll frame.
	local HQSF1 = CreateFrame("Frame","HQSF1",Historia_HQ_I)
	HQSF1:SetPoint("TOPLEFT", "Historia_HQ_I", "TOPLEFT", 0, -24)
	HQSF1:SetPoint("BOTTOMRIGHT", "Historia_HQ_I", "TOPLEFT", 540, Historia_HQ_I_Height*-1)
	HQSF1:SetBackdrop((cfg.Historia_backdrop2))

	--  Create the container for the Quests scroll bar.
	local HQSF1_bar = CreateFrame("Frame","HQSF1_bar",HQSF1)
	HQSF1_bar:SetPoint("TOPRIGHT", "HQSF1", 0, 0)
	HQSF1_bar:SetPoint("BOTTOMLEFT", "HQSF1", "BOTTOMRIGHT", -24, 0)
	HQSF1_bar:SetBackdrop(cfg.Historia_backdrop2)	

	--  Create the list of buttons that go into the Quests scroll frame
	HQSF1.list = {}
	for i=1,Historia_HQ_NO_SCROLLBUTTONS do
		HQSF1.list[i] = CreateFrame("Button",nil,HQSF1)
		HQSF1.list[i]:SetSize(540,16)
		HQSF1.list[i]:SetPoint("TOPLEFT",HQSF1,"TOPLEFT",8,(i-1)*-16-4)
		HQSF1.list[i]:Show()
		
		HQSF1.list[i].name1 = HQSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		HQSF1.list[i].name1:SetSize(160,16)
		HQSF1.list[i].name1:SetPoint("LEFT",0,0)	
		HQSF1.list[i].name1:SetJustifyH("LEFT") 

		HQSF1.list[i].name2 = HQSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		HQSF1.list[i].name2:SetSize(380,16)
		HQSF1.list[i].name2:SetPoint("LEFT", HQSF1.list[i].name1, "RIGHT",4,0)
		HQSF1.list[i].name2:SetJustifyH("LEFT") 
	end	
	
	-- 	Create the scroll frame
	HQSF1.scrollFrame = CreateFrame("ScrollFrame","HQSF1_scrollFrame",HQSF1,"FauxScrollFrameTemplate")
	HQSF1.scrollFrame:SetPoint("TOPLEFT",HQSF1,"TOPLEFT",0,-2)
	HQSF1.scrollFrame:SetPoint("BOTTOMRIGHT",HQSF1,"BOTTOMRIGHT",-26,2)
	HQSF1.scrollFrame:SetScript("OnVerticalScroll",function(self,offset)
	FauxScrollFrame_OnVerticalScroll(self,offset,16,HQSF1_ScrollFrameUpdate)
	end)	
end 


-------------------------------------------------------------------------------
--  Fill the Quests scroll table
-------------------------------------------------------------------------------
function Historia_HQ_Build_Table(id)
	row_count = 0
	Historia_Quests_Table = {}
	Historia_Quests_Scroll_Table = {}	

	for idx = 1, #HistoriaLocalDb.Quests do
		Historia_Quests_Table = {}
		row_count = row_count + 1
		
		Historia_Quests_Table.Text		= HistoriaLocalDb.Quests[idx].Complete_questText
		Historia_Quests_Table.Time		= HistoriaLocalDb.Quests[idx].time
		tinsert(Historia_Quests_Scroll_Table,1,Historia_Quests_Table)
	end	

	for i=1,cfg.Historia_HIQ1_Buttons do
		if HistoriaLocalDb.Quests[cfg.Historia_HIQ1_Text[i]] then
			Historia_HQ_JJ[i].name2:SetText("")
			Historia_HQ_JJ[i].name2:SetText(format(date("%a, %b %d %Y %H:%M",HistoriaLocalDb.Quests[cfg.Historia_HIQ1_Text[i]].time)))
		end
	end	
end	


-------------------------------------------------------------------------------
--  Quests scroll table the scrolling part.
-------------------------------------------------------------------------------
function HQSF1_ScrollFrameUpdate()
	local offset = FauxScrollFrame_GetOffset(HQSF1.scrollFrame)
	FauxScrollFrame_Update(HQSF1.scrollFrame, row_count, Historia_HQ_NO_SCROLLBUTTONS, 16)

	for i = 1, Historia_HQ_NO_SCROLLBUTTONS do
		local idx = offset + i
		if idx <= row_count then
			HQSF1.list[i].name1:SetText(format(date("%a, %b %d %Y %H:%M", Historia_Quests_Scroll_Table[idx].Time)))
			HQSF1.list[i].name2:SetText(Historia_Quests_Scroll_Table[idx].Text)
			HQSF1.list[i]:Show()
		else
			HQSF1.list[i]:Hide()
		end	
	end	
end


-------------------------------------------------------------------------------
--	Create the rest of the Quest tab
-------------------------------------------------------------------------------
function Historia_Quests_TheRest()
	--  Create a reference frame for the rest of the Quests info.
	local Historia_HQ_J = CreateFrame("Frame","Historia_HQ_J",Historia_HQ)
	Historia_HQ_J:SetPoint("TOPRIGHT", "Historia_HQ_H", "BOTTOMRIGHT", 0, -16)
	Historia_HQ_J:SetPoint("BOTTOMLEFT", "Historia_HQ", "BOTTOMRIGHT", -288, 0)	
	--Historia_HQ_J:SetBackdrop(cfg.Historia_backdrop2)	

	local Historia_HQ_JH = CreateFrame("Frame","Historia_HQ_JH",Historia_HQ_J)
	Historia_HQ_JH:SetPoint("TOPLEFT","Historia_HQ_J",0,0)
	Historia_HQ_JH:SetPoint("BOTTOMRIGHT","Historia_HQ_J","TOPRIGHT",0,-24)
	Historia_HQ_JH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HQ_JH.F1 = Historia_HQ_JH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HQ_JH.F1:SetPoint("CENTER","Historia_HQ_JH",0,0)
	Historia_HQ_JH.F1:SetText(L["Statistics"])	
	
	local Historia_HQ_JJ = CreateFrame("Frame","Historia_HQ_JJ",Historia_HQ_J)
	Historia_HQ_JJ:SetPoint("TOPLEFT","Historia_HQ_JH","BOTTOMLEFT",0,0)
	Historia_HQ_JJ:SetPoint("BOTTOMRIGHT","Historia_HQ_J",0,-0)
	--Historia_HQ_JJ:SetBackdrop(cfg.Historia_backdrop2)	

	Historia_HQ_JJ.list = {}
	for i=1,cfg.Historia_HIQ1_Buttons do
		Historia_HQ_JJ[i] = CreateFrame("Button",nil,Historia_HQ_JJ)
		Historia_HQ_JJ[i]:SetSize(64,32)
		Historia_HQ_JJ[i]:SetPoint("TOPLEFT",Historia_HQ_JJ,"TOPLEFT",0,(i-1)*-32-4)
		Historia_HQ_JJ[i]:SetBackdrop(cfg.Historia_backdrop2)
		Historia_HQ_JJ[i]:Show()
		
		Historia_HQ_JJ[i].name1 = Historia_HQ_JJ[i]:CreateFontString(nil,"ARTWORK","GameFontNormalHuge")
		Historia_HQ_JJ[i].name1:SetSize(64,32)
		Historia_HQ_JJ[i].name1:SetPoint("CENTER",0,0)	
		Historia_HQ_JJ[i].name1:SetText(cfg.colors["Silver"] .. cfg.Historia_HIQ1_Text[i] .. cfg.colors["End"])		

		Historia_HQ_JJ[i] = CreateFrame("Button",nil,Historia_HQ_JJ)
		Historia_HQ_JJ[i]:SetSize(224,32)
		Historia_HQ_JJ[i]:SetPoint("TOPLEFT",Historia_HQ_JJ,"TOPLEFT",64,(i-1)*-32-4)
		Historia_HQ_JJ[i]:SetBackdrop(cfg.Historia_backdrop2)
		Historia_HQ_JJ[i]:Show()

		Historia_HQ_JJ[i].name2 = Historia_HQ_JJ[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HQ_JJ[i].name2:SetSize(160,32)
		Historia_HQ_JJ[i].name2:SetPoint("LEFT",8,0)	
		Historia_HQ_JJ[i].name2:SetJustifyH("LEFT")	
		Historia_HQ_JJ[i].name2:SetText(L["Not recorded"])		
	end	
end


-------------------------------------------------------------------------------
--  Handle the Quests Tab
-------------------------------------------------------------------------------
function Historia_HQ_Update()
	Historia_HQ_Build_Table()
	
	HQSF1.scrollFrame.ScrollBar:SetValue(0)	
	HQSF1_ScrollFrameUpdate()	
end


