--[[	*** Historia ***
Written by : Yukyuk, EU-Moonglade
--]]

-------------------------------------------------------------------------------
--  From _Global to local.
-------------------------------------------------------------------------------
local _G = _G


-------------------------------------------------------------------------------
--  AddOn namespace.
-------------------------------------------------------------------------------
local FOLDER_NAME, private = ...

local cfg = private.cfg
local addon = cfg.addon_name


-------------------------------------------------------------------------------
--  Libstubs.
-------------------------------------------------------------------------------
local L 		= LibStub("AceLocale-3.0"):GetLocale("Historia")
local LibQTip 	= LibStub:GetLibrary("LibQTip-1.0")


-------------------------------------------------------------------------------
--	Local variables
-------------------------------------------------------------------------------
local row_count = 0
local Historia_HT_NO_SCROLLBUTTONS = 24		--  number of scroll buttons for the TimeLine frame
local Historia_NUMBEROFTIMELINETABS = 3		--	number of selection buttons in the TimeLine tab
local Historia_TimeLine_Tab = {}			--	this variable holds the selection buttons
local Historia_TimeLine_Table = {}			--	this varaible holds the TimeLine dates selected from the database
local Historia_TimeLine_Months_Table = {}	--  this table holds the data per month
local Historia_TimeLine_Years_Table = {}	--	this table holds the data per year
local Historia_TimeLine_Scroll_Table = {}	--	this variable holds the selected lines that go into the scroll table

--  Define the icons of the TimeLine tab .
 local TimeLine_icon = {
	[1] = "Interface\\ICONS\\INV_Letter_07",
	[2] = "Interface\\ICONS\\INV_Letter_08",
	[3] = "Interface\\ICONS\\INV_Letter_14",	
}

local Historia_Timeline_Tabs_Number = 4
local Historia_Timeline_Tabs_Text = {LEVEL,TUTORIAL_TITLE38,SKILLS,QUESTS_LABEL}

local Historia_NUMBER_OF_YEARS = 10
local Historia_NUMBER_OF_MONTHS = 12
local Historia_NUMBER_OF_DAYS = 31
local DTY = {"2015", "2016", "2017", "2018", "2019", "2020", "2021", "2022", "2023", "2024"}
local DTM = {"01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12"}
local DTD = {"01", "02", "03", "04", "05", "06", "07", "08", "09", "10", "11", "12", "13", "14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", "25", "26", "27", "28", "29", "30", "31"}

local day_select = false 
local month_select = false
local year_select = false

local Historia_TimeLine_Months_Quests = 0
local Historia_TimeLine_Months_Skills = 0
local Historia_TimeLine_Months_Professions = 0
local Historia_TimeLine_Months_Levels = 0

local Historia_TimeLine_Years_Quests = 0
local Historia_TimeLine_Years_Skills = 0
local Historia_TimeLine_Years_Professions = 0
local Historia_TimeLine_Years_Levels = 0

local Best_day_Level		 = {[1] = -99999,[2] = "", [3] = "", [4] = ""}
local Best_day_Professions	 = {[1] = -99999,[2] = "", [3] = "", [4] = ""}
local Best_day_Skills	 = {[1] = -99999,[2] = "", [3] = "", [4] = ""}
local Best_day_Quests		 = {[1] = -99999,[2] = "", [3] = "", [4] = ""}

local Best_month_Level		 = {[1] = -99999,[2] = "", [3] = ""}
local Best_month_Professions = {[1] = -99999,[2] = "", [3] = ""}
local Best_month_Skills = {[1] = -99999,[2] = "", [3] = ""}
local Best_month_Quests		 = {[1] = -99999,[2] = "", [3] = ""}

local Best_year_Level		 = {[1] = -99999,[2] = ""}
local Best_year_Professions	 = {[1] = -99999,[2] = ""}
local Best_year_Skills = {[1] = -99999,[2] = ""}
local Best_year_Quests		 = {[1] = -99999,[2] = ""}

--------------------------------------------------------------------------------
--  This is the Historia time line frame
--------------------------------------------------------------------------------	
function Historia_TimeLine()
	local Historia_HT = CreateFrame("Frame","Historia_HT",Historia_UI)
	Historia_HT:SetPoint("TOP", "Historia_UI", 0, -16)
	Historia_HT:SetPoint("BOTTOM", "Historia_UI", 0, 16)
	Historia_HT:SetPoint("LEFT", "Historia_UI", 16, 0)
	Historia_HT:SetPoint("RIGHT", "Historia_UI", -16, 0)
	Historia_HT:SetBackdrop(cfg.Historia_backdrop3)
	
	--  Create a frame for the header time line info.
	local Historia_HT_H = CreateFrame("Frame","Historia_HT_H",Historia_HT)
	Historia_HT_H:SetPoint("TOPLEFT","Historia_HT",0,0)
	Historia_HT_H:SetPoint("BOTTOMRIGHT","Historia_HT","TOPRIGHT",0,-48)
	Historia_HT_H:SetBackdrop(cfg.Historia_backdrop2)		
	
	Historia_HT_H.F1 = Historia_HT_H:CreateFontString(nil,"ARTWORK","GameFontNormalHuge")
	Historia_HT_H.F1:SetPoint("CENTER","Historia_HT_H",0,0)
	Historia_HT_H.F1:SetText(L["Time line"])	
	
	Historia_TimeLine_Scrollframe()
	Historia_TimeLine_TheRest()	

	Historia_HT:Hide()
end	


-------------------------------------------------------------------------------
--  Fill the TimeLine scroll table
-------------------------------------------------------------------------------
function Historia_TimeLine_Scrollframe()
	--  Create a reference frame for the rest of the TimeLine info.
	local Historia_HT_I = CreateFrame("Frame","Historia_HT_I",Historia_HT)
	Historia_HT_I:SetPoint("TOPLEFT", "Historia_HT_H", "BOTTOMLEFT", 0, -16)
	Historia_HT_I:SetPoint("BOTTOMRIGHT", "Historia_HT", "BOTTOMRIGHT", 0, 0)
	local Historia_HT_I_Width = Historia_HT_I:GetWidth()	
	local Historia_HT_I_Height = Historia_HT_I:GetHeight()

	--  Create a frame for the header TimeLine text.
	local Historia_HT_IH = CreateFrame("Frame","Historia_HT_IH",Historia_HT_I)
	Historia_HT_IH:SetPoint("TOPLEFT","Historia_HT_I",0,0)
	Historia_HT_IH:SetPoint("BOTTOMRIGHT","Historia_HT_I","TOPLEFT",320,-24)
	Historia_HT_IH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HT_IH.F1 = Historia_HT_IH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HT_IH.F1:SetPoint("CENTER","Historia_HT_IH",0,0)
	Historia_HT_IH.F1:SetText(L["Time line"])	
	
	--  Create the container for the TimeLine scroll frame.
	local HTSF1 = CreateFrame("Frame","HTSF1",Historia_HT_I)
	HTSF1:SetPoint("TOPLEFT", "Historia_HT_I", "TOPLEFT", 0, -24)
	HTSF1:SetPoint("BOTTOMRIGHT", "Historia_HT_I", "TOPLEFT", 320, Historia_HT_I_Height*-1)
	HTSF1:SetBackdrop((cfg.Historia_backdrop2))

	--  Create the container for the TimeLine scroll bar.
	local HTSF1_bar = CreateFrame("Frame","HTSF1_bar",HTSF1)
	HTSF1_bar:SetPoint("TOPRIGHT", "HTSF1", 0, 0)
	HTSF1_bar:SetPoint("BOTTOMLEFT", "HTSF1", "BOTTOMRIGHT", -24, 0)
	HTSF1_bar:SetBackdrop(cfg.Historia_backdrop2)	

	--  Create the list of buttons that go into the TimeLine scroll frame
	HTSF1.list = {}
	for i=1,Historia_HT_NO_SCROLLBUTTONS do
		HTSF1.list[i] = CreateFrame("Button",nil,HTSF1)
		HTSF1.list[i]:SetSize(296,16)
		HTSF1.list[i]:SetPoint("TOPLEFT",HTSF1,"TOPLEFT",8,(i-1)*-16-4)
		HTSF1.list[i]:Show()
		
		HTSF1.list[i].Header = HTSF1.list[i]:CreateTexture(nil,"BACKGROUND")
		HTSF1.list[i].Header:SetTexture("Interface\\ACHIEVEMENTFRAME\\UI-GuildAchievement-Parchment-Horizontal-Desaturated")
		HTSF1.list[i].Header:SetSize(288, 16)
		HTSF1.list[i].Header:SetPoint("TOPLEFT",0,0)

		HTSF1.list[i].name0 = HTSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		HTSF1.list[i].name0:SetSize(288,16)
		HTSF1.list[i].name0:SetPoint("LEFT",4,0)
		HTSF1.list[i].name0:SetJustifyH("LEFT") 	

		HTSF1.list[i].Detail = HTSF1.list[i]:CreateTexture(nil,"BACKGROUND")
		HTSF1.list[i].Detail:SetTexture("Interface\\ACHIEVEMENTFRAME\\UI-GuildAchievement-AchievementBackground")
		HTSF1.list[i].Detail:SetTexCoord(0,0.3,0,0.3)
		HTSF1.list[i].Detail:SetSize(288, 16)
		HTSF1.list[i].Detail:SetPoint("TOPLEFT",0,0)

		HTSF1.list[i].name1 = HTSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		HTSF1.list[i].name1:SetSize(112,16)
		HTSF1.list[i].name1:SetPoint("LEFT",4,0)
		HTSF1.list[i].name1:SetJustifyH("LEFT") 	
		
		HTSF1.list[i].name2 = HTSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		HTSF1.list[i].name2:SetSize(16,16)
		HTSF1.list[i].name2:SetPoint("LEFT", HTSF1.list[i].name1, "RIGHT",4,0)
		HTSF1.list[i].name2:SetJustifyH("LEFT")
		HTSF1.list[i].name2:SetText(":")
		
		HTSF1.list[i].name3 = HTSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		HTSF1.list[i].name3:SetSize(112,16)
		HTSF1.list[i].name3:SetPoint("LEFT", HTSF1.list[i].name2, "RIGHT",4,0)
		HTSF1.list[i].name3:SetJustifyH("LEFT") 		
		
		HTSF1.list[i].icon1 = HTSF1.list[i]:CreateTexture(nil,"ARTWORK")
		HTSF1.list[i].icon1:SetSize(16,16)
		HTSF1.list[i].icon1:SetPoint("LEFT",4,0)		
	
		HTSF1.list[i].name4 = HTSF1.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		HTSF1.list[i].name4:SetSize(200,16)
		HTSF1.list[i].name4:SetPoint("LEFT", HTSF1.list[i].icon1, "RIGHT",4,0)
		HTSF1.list[i].name4:SetJustifyH("LEFT") 
	end	
	
	-- 	Create the scroll frame
	HTSF1.scrollFrame = CreateFrame("ScrollFrame","HTSF1_scrollFrame",HTSF1,"FauxScrollFrameTemplate")
	HTSF1.scrollFrame:SetPoint("TOPLEFT",HTSF1,"TOPLEFT",0,-2)
	HTSF1.scrollFrame:SetPoint("BOTTOMRIGHT",HTSF1,"BOTTOMRIGHT",-26,2)
	HTSF1.scrollFrame:SetScript("OnVerticalScroll",function(self,offset)
	FauxScrollFrame_OnVerticalScroll(self,offset,16,HTSF1_ScrollFrameUpdate)
	end)	
	
	--	Create the Day/Month/Year gold buttons
	for i = 1,Historia_NUMBEROFTIMELINETABS do
		Historia_TimeLine_Tab[i] = CreateFrame("Button",nil,Historia_HT_I)
		Historia_TimeLine_Tab[i]:SetSize(40,40)
		Historia_TimeLine_Tab[i]:SetPoint("TOPLEFT",HTSF1,"TOPRIGHT",0,(i-1)*-40)
		Historia_TimeLine_Tab[i]:SetBackdrop(cfg.Historia_backdrop0)
		Historia_TimeLine_Tab[i]:Show()
		Historia_TimeLine_Tab[i]:SetScript("OnClick", function(self, button)
			Historia_HT_Build_Table(i)		
		end)	
		Historia_TimeLine_Tab[i]:SetScript("OnEnter", function(self, button)
			Historia_TimeLine_Tab[i].te1:Show()
		end)		
		Historia_TimeLine_Tab[i]:SetScript("OnLeave", function(self, button)
			Historia_TimeLine_Tab[i].te1:Hide()
		end)		
		
		Historia_TimeLine_Tab[i].te1 = Historia_TimeLine_Tab[i]:CreateTexture(nil,"ARTWORK")
		Historia_TimeLine_Tab[i].te1:SetTexture("Interface\\ContainerFrame\\UI-Icon-QuestBorder")
		Historia_TimeLine_Tab[i].te1:SetPoint("TOPLEFT", Historia_TimeLine_Tab[i], 2, -2)
		Historia_TimeLine_Tab[i].te1:SetPoint("BOTTOMRIGHT", Historia_TimeLine_Tab[i], -2, 2)	
		Historia_TimeLine_Tab[i].te1:Hide()
		
		Historia_TimeLine_Tab[i].te2 = Historia_TimeLine_Tab[i]:CreateTexture(nil,"ARTWORK")
		Historia_TimeLine_Tab[i].te2:SetTexture(TimeLine_icon[i])
		Historia_TimeLine_Tab[i].te2:SetPoint("TOPLEFT", Historia_TimeLine_Tab[i], 4, -4)
		Historia_TimeLine_Tab[i].te2:SetPoint("BOTTOMRIGHT", Historia_TimeLine_Tab[i], -4, 4)	
		Historia_TimeLine_Tab[i].te2:Show()		
	end
end 


-------------------------------------------------------------------------------
--  Build the per Day table
-------------------------------------------------------------------------------
--	The following fields are stored in Historia_TimeLine_Table
--	Kind		What kind of line is this, 0 = Header, 1 = Quests, 2 = Skills,
--										   3 = Professions, 4 = levels, 5 = Gold
--	Date		Date of the datail line
--	TimeLine	Number of recorded Quests ect
--	Sign		Sign for the amount of gold, 1 is positive, -1 is negative
--	Amount		Total amount of gold earned/spent that day
-------------------------------------------------------------------------------
function Historia_HT_Build_PerDay()
	row_count = 0
	Historia_TimeLine_Table = {}
	Historia_TimeLine_Scroll_Table = {}
	Historia_TimeLine_Months_Table = {}
	Historia_TimeLine_Years_Table = {}	
	
	for i = 1, Historia_NUMBER_OF_YEARS do
		if HistoriaLocalDb.Dates[DTY[i]] then
			--	Initialize the years data
			year_select = false
			Historia_TimeLine_Years_Quests = 0
			Historia_TimeLine_Years_Skills = 0
			Historia_TimeLine_Years_Professions = 0
			Historia_TimeLine_Years_Levels = 0			
			for j = 1, Historia_NUMBER_OF_MONTHS do
				if HistoriaLocalDb.Dates[DTY[i]][DTM[j]] then
					--	Initialize the months data
					month_select = false
					Historia_TimeLine_Months_Quests = 0
					Historia_TimeLine_Months_Skills = 0
					Historia_TimeLine_Months_Professions = 0
					Historia_TimeLine_Months_Levels = 0
					for k = 1, Historia_NUMBER_OF_DAYS do
						if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]] then
							day_select = false
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests > 0 then
								Historia_TimeLine_Table = {}
								row_count = row_count + 1
								Historia_TimeLine_Table.Kind = 1
								Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
								Historia_TimeLine_Table.TimeLine = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests
								Historia_TimeLine_Table.Sign = 0	
								table.insert(Historia_TimeLine_Scroll_Table,1,Historia_TimeLine_Table)
								Historia_TimeLine_Months_Quests = Historia_TimeLine_Months_Quests + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests
								Historia_TimeLine_Years_Quests = Historia_TimeLine_Years_Quests + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests
								day_select = true
							end	
						
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills > 0 then
								Historia_TimeLine_Table = {}
								row_count = row_count + 1
								Historia_TimeLine_Table.Kind = 2
								Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
								Historia_TimeLine_Table.TimeLine = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills
								Historia_TimeLine_Table.Sign = 0	
								table.insert(Historia_TimeLine_Scroll_Table,1,Historia_TimeLine_Table)
								Historia_TimeLine_Months_Skills = Historia_TimeLine_Months_Skills + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills
								Historia_TimeLine_Years_Skills = Historia_TimeLine_Years_Skills + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills								
								day_select = true
							end
							
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions > 0 then
								Historia_TimeLine_Table = {}
								row_count = row_count + 1
								Historia_TimeLine_Table.Kind = 3
								Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
								Historia_TimeLine_Table.TimeLine = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions
								Historia_TimeLine_Table.Sign = 0	
								table.insert(Historia_TimeLine_Scroll_Table,1,Historia_TimeLine_Table)
								Historia_TimeLine_Months_Professions = Historia_TimeLine_Months_Professions + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions
								Historia_TimeLine_Years_Professions = Historia_TimeLine_Years_Professions + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions								
								day_select = true
							end
							
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level > 0 then
								Historia_TimeLine_Table = {}
								row_count = row_count + 1
								Historia_TimeLine_Table.Kind = 4
								Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
								Historia_TimeLine_Table.TimeLine = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level
								Historia_TimeLine_Table.Sign = 0	
								table.insert(Historia_TimeLine_Scroll_Table,1,Historia_TimeLine_Table)
								Historia_TimeLine_Months_Levels = Historia_TimeLine_Months_Levels + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level
								Historia_TimeLine_Years_Levels = Historia_TimeLine_Years_Levels + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level								
								day_select = true
							end
							
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Start ~=  
								HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Current then
								Historia_TimeLine_Table = {}
								row_count = row_count + 1
								Historia_TimeLine_Table.Kind = 5
								Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
								amount = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Current - HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Gold_Start
								if amount > 0 then 
									Historia_TimeLine_Table.Amount = amount
									Historia_TimeLine_Table.Sign = 1	
								elseif 	amount < 0 then 
									Historia_TimeLine_Table.Amount = amount * -1
									Historia_TimeLine_Table.Sign = -1
								end	
								table.insert(Historia_TimeLine_Scroll_Table,1,Historia_TimeLine_Table)
								day_select = true
							end							
							
							if day_select then
								Historia_TimeLine_Table = {}
								row_count = row_count + 1
								Historia_TimeLine_Table.Kind = 0
								Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],DTD[k])
								Historia_TimeLine_Table.TimeLine = 0
								Historia_TimeLine_Table.Sign = 0	
								table.insert(Historia_TimeLine_Scroll_Table,1,Historia_TimeLine_Table)
							end
						end
						
					end
					--	Store the collected month data
					if Historia_TimeLine_Months_Quests > 0 then
						Historia_TimeLine_Table = {}
						Historia_TimeLine_Table.Kind = 1
						Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],"")
						Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Months_Quests
						Historia_TimeLine_Table.Sign = 0	
						table.insert(Historia_TimeLine_Months_Table,1,Historia_TimeLine_Table)
						month_select = true
					end	
					if Historia_TimeLine_Months_Skills > 0 then
						Historia_TimeLine_Table = {}
						Historia_TimeLine_Table.Kind = 2
						Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],"")
						Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Months_Skills
						Historia_TimeLine_Table.Sign = 0	
						table.insert(Historia_TimeLine_Months_Table,1,Historia_TimeLine_Table)
						month_select = true
					end	
					if Historia_TimeLine_Months_Professions > 0 then
						Historia_TimeLine_Table = {}
						Historia_TimeLine_Table.Kind = 3
						Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],"")
						Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Months_Professions
						Historia_TimeLine_Table.Sign = 0	
						table.insert(Historia_TimeLine_Months_Table,1,Historia_TimeLine_Table)
						month_select = true
					end	
					if Historia_TimeLine_Months_Levels > 0 then
						Historia_TimeLine_Table = {}
						Historia_TimeLine_Table.Kind = 4
						Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],"")
						Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Months_Levels
						Historia_TimeLine_Table.Sign = 0	
						table.insert(Historia_TimeLine_Months_Table,1,Historia_TimeLine_Table)
						month_select = true
					end						
					if month_select then
						Historia_TimeLine_Table = {}
						Historia_TimeLine_Table.Kind = 0
						Historia_TimeLine_Table.Date = cfg.Historia_FormatDate(DTY[i],DTM[j],"")
						Historia_TimeLine_Table.TimeLine = 0
						Historia_TimeLine_Table.Sign = 0	
						table.insert(Historia_TimeLine_Months_Table,1,Historia_TimeLine_Table)
					end	
				end
			end	
			--	Store the collected year data
			if Historia_TimeLine_Years_Quests > 0 then
				Historia_TimeLine_Table = {}
				Historia_TimeLine_Table.Kind = 1
				Historia_TimeLine_Table.Date = DTY[i]
				Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Years_Quests
				Historia_TimeLine_Table.Sign = 0	
				table.insert(Historia_TimeLine_Years_Table,1,Historia_TimeLine_Table)
				year_select = true
			end	
			if Historia_TimeLine_Years_Skills > 0 then
				Historia_TimeLine_Table = {}
				Historia_TimeLine_Table.Kind = 2
				Historia_TimeLine_Table.Date = DTY[i]
				Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Years_Skills
				Historia_TimeLine_Table.Sign = 0	
				table.insert(Historia_TimeLine_Years_Table,1,Historia_TimeLine_Table)
				year_select = true
			end	
			if Historia_TimeLine_Years_Professions > 0 then
				Historia_TimeLine_Table = {}
				Historia_TimeLine_Table.Kind = 3
				Historia_TimeLine_Table.Date = DTY[i]
				Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Years_Professions
				Historia_TimeLine_Table.Sign = 0	
				table.insert(Historia_TimeLine_Years_Table,1,Historia_TimeLine_Table)
				year_select = true
			end	
			if Historia_TimeLine_Years_Levels > 0 then
				Historia_TimeLine_Table = {}
				Historia_TimeLine_Table.Kind = 4
				Historia_TimeLine_Table.Date = DTY[i]
				Historia_TimeLine_Table.TimeLine = Historia_TimeLine_Years_Levels
				Historia_TimeLine_Table.Sign = 0	
				table.insert(Historia_TimeLine_Years_Table,1,Historia_TimeLine_Table)
				year_select = true
			end				
			if year_select then	
				Historia_TimeLine_Table = {}
				Historia_TimeLine_Table.Kind = 0
				Historia_TimeLine_Table.Date = DTY[i]
				Historia_TimeLine_Table.TimeLine = 0
				Historia_TimeLine_Table.Sign = 0	
				table.insert(Historia_TimeLine_Years_Table,1,Historia_TimeLine_Table)
			end						
		end	
	end	
end


-------------------------------------------------------------------------------
--  Build per Month time line
-------------------------------------------------------------------------------
function Historia_HT_Build_PerMonth()
	row_count = #Historia_TimeLine_Months_Table
	Historia_TimeLine_Scroll_Table = {}
	Historia_TimeLine_Scroll_Table = Historia_TimeLine_Months_Table
end


-------------------------------------------------------------------------------
--  Build per Year time line
-------------------------------------------------------------------------------
function Historia_HT_Build_PerYear()
	row_count = #Historia_TimeLine_Years_Table
	Historia_TimeLine_Scroll_Table = {}
	Historia_TimeLine_Scroll_Table = Historia_TimeLine_Years_Table
end


-------------------------------------------------------------------------------
--  Fill the TimeLine scroll table
--	Fill the extensions part
-------------------------------------------------------------------------------
function Historia_HT_Build_Table(id)
	if id == 1 then
		Historia_HT_Build_PerDay()
	elseif id == 2 then
		Historia_HT_Build_PerMonth()
	elseif id == 3 then	
		Historia_HT_Build_PerYear()
	end	
	
	HTSF1.scrollFrame.ScrollBar:SetValue(0)	
	HTSF1_ScrollFrameUpdate()
end	


-------------------------------------------------------------------------------
--  TimeLine scroll table the scrolling part.
-------------------------------------------------------------------------------
function HTSF1_ScrollFrameUpdate()
	local offset = FauxScrollFrame_GetOffset(HTSF1.scrollFrame)
	FauxScrollFrame_Update(HTSF1.scrollFrame, row_count, Historia_HT_NO_SCROLLBUTTONS, 16)

	for i = 1, Historia_HT_NO_SCROLLBUTTONS do
		local idx = offset + i
		if idx <= row_count then
			if Historia_TimeLine_Scroll_Table[idx].Kind == 0 then
				HTSF1.list[i].name0:SetText(Historia_TimeLine_Scroll_Table[idx].Date)
				HTSF1.list[i].name1:SetText("")
				HTSF1.list[i].name2:SetText("")				
				HTSF1.list[i].name3:SetText("")
				HTSF1.list[i].icon1:Hide()
				HTSF1.list[i].name4:SetText("")
				HTSF1.list[i].Header:Show()
				HTSF1.list[i].Detail:Hide()
			elseif Historia_TimeLine_Scroll_Table[idx].Kind == 5 then
				HTSF1.list[i].name0:SetText("")			
				HTSF1.list[i].name1:SetText("")
				HTSF1.list[i].name2:SetText("")					
				HTSF1.list[i].name3:SetText("")
				if Historia_TimeLine_Scroll_Table[idx].Sign == 1 then
					HTSF1.list[i].icon1:SetTexture(cfg.CTX[2])
				else
					HTSF1.list[i].icon1:SetTexture(cfg.CTX[3])
				end	
				HTSF1.list[i].icon1:Show()
				HTSF1.list[i].name4:SetText(GetCoinTextureString(Historia_TimeLine_Scroll_Table[idx].Amount))			
				HTSF1.list[i].Header:Hide()
				HTSF1.list[i].Detail:Show()
			else
				HTSF1.list[i].name0:SetText("")
				if Historia_TimeLine_Scroll_Table[idx].Kind == 1 then
					HTSF1.list[i].name1:SetText(QUESTS_LABEL)
				elseif Historia_TimeLine_Scroll_Table[idx].Kind == 2 then
					HTSF1.list[i].name1:SetText(SKILLS)
				elseif Historia_TimeLine_Scroll_Table[idx].Kind == 3 then
					HTSF1.list[i].name1:SetText(TUTORIAL_TITLE38)
				elseif Historia_TimeLine_Scroll_Table[idx].Kind == 4 then
					HTSF1.list[i].name1:SetText(LEVEL)					
				end
				HTSF1.list[i].name2:SetText(":")					
				HTSF1.list[i].name3:SetText(Historia_TimeLine_Scroll_Table[idx].TimeLine)
				HTSF1.list[i].icon1:Hide()
				HTSF1.list[i].name4:SetText("")				
				HTSF1.list[i].Header:Hide()
				HTSF1.list[i].Detail:Show()			
			end

			HTSF1.list[i]:Show()
		else
			HTSF1.list[i]:Hide()
		end	
	end	
end


-------------------------------------------------------------------------------
--	Create and fill the rest of the data
-------------------------------------------------------------------------------
function Historia_TimeLine_TheRest()
	--  Create a reference frame for the rest of the Time line info.
	local Historia_HT_J = CreateFrame("Frame","Historia_HT_J",Historia_HT)
	Historia_HT_J:SetPoint("TOPRIGHT", "Historia_HT_H", "BOTTOMRIGHT", 0, -16)
	Historia_HT_J:SetPoint("BOTTOMLEFT", "Historia_HT", "BOTTOMRIGHT", -320, 0)

	local Historia_HT_JH = CreateFrame("Frame","Historia_HT_JH",Historia_HT_J)
	Historia_HT_JH:SetPoint("TOPRIGHT","Historia_HT_J",0,0)
	Historia_HT_JH:SetPoint("BOTTOMLEFT","Historia_HT_J","TOPRIGHT",-320,-24)
	Historia_HT_JH:SetBackdrop(cfg.Historia_backdrop2)	
	
	Historia_HT_JH.F1 = Historia_HT_JH:CreateFontString(nil,"ARTWORK","GameFontWhite")
	Historia_HT_JH.F1:SetPoint("CENTER","Historia_HT_JH",0,0)
	Historia_HT_JH.F1:SetText(L["Statistics"])

	--  Create a frame for the best days.
	local Historia_HT_JJ = CreateFrame("Frame","Historia_HT_JJ",Historia_HT_J)
	Historia_HT_JJ:SetPoint("TOPLEFT","Historia_HT_JH","BOTTOMLEFT",0,-16)
	Historia_HT_JJ:SetPoint("BOTTOMRIGHT","Historia_HT_JH","BOTTOMLEFT",320,-104)
	Historia_HT_JJ:SetBackdrop(cfg.Historia_backdrop2)

	Historia_HT_JJ.F1 = Historia_HT_JJ:CreateFontString(nil,"ARTWORK","GameFontGreen")
	Historia_HT_JJ.F1:SetPoint("Top","Historia_HT_JJ",0,-4)
	Historia_HT_JJ.F1:SetText(L["Best days"])

	Historia_HT_JJ.list = {}
	for i=1,Historia_Timeline_Tabs_Number do
		Historia_HT_JJ.list[i] = CreateFrame("Button",nil,Historia_HT_JJ)
		Historia_HT_JJ.list[i]:SetSize(320,16)
		Historia_HT_JJ.list[i]:SetPoint("TOPRIGHT",Historia_HT_JJ,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HT_JJ.list[i]:Show()
		
		Historia_HT_JJ.list[i].name1 = Historia_HT_JJ.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HT_JJ.list[i].name1:SetSize(112,16)
		Historia_HT_JJ.list[i].name1:SetPoint("LEFT",4,0)	
		Historia_HT_JJ.list[i].name1:SetJustifyH("LEFT") 
		Historia_HT_JJ.list[i].name1:SetText(Historia_Timeline_Tabs_Text[i])
		
		Historia_HT_JJ.list[i].name2 = Historia_HT_JJ.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HT_JJ.list[i].name2:SetSize(40,16)
		Historia_HT_JJ.list[i].name2:SetPoint("LEFT", Historia_HT_JJ.list[i].name1, "RIGHT",4,0)	
		Historia_HT_JJ.list[i].name2:SetJustifyH("CENTER")

		Historia_HT_JJ.list[i].name3 = Historia_HT_JJ.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HT_JJ.list[i].name3:SetSize(160,16)
		Historia_HT_JJ.list[i].name3:SetPoint("LEFT", Historia_HT_JJ.list[i].name2, "RIGHT",4,0)
		Historia_HT_JJ.list[i].name3:SetJustifyH("LEFT") 
	end	
	
	--  Create a frame for the best Months days.
	local Historia_HT_JK = CreateFrame("Frame","Historia_HT_JK",Historia_HT_J)
	Historia_HT_JK:SetPoint("TOPLEFT","Historia_HT_JJ","BOTTOMLEFT",0,-16)
	Historia_HT_JK:SetPoint("BOTTOMRIGHT","Historia_HT_JJ","BOTTOMLEFT",320,-104)
	Historia_HT_JK:SetBackdrop(cfg.Historia_backdrop2)

	Historia_HT_JK.F1 = Historia_HT_JK:CreateFontString(nil,"ARTWORK","GameFontGreen")
	Historia_HT_JK.F1:SetPoint("Top","Historia_HT_JK",0,-4)
	Historia_HT_JK.F1:SetText(L["Best months"])	
	
	Historia_HT_JK.list = {}
	for i=1,Historia_Timeline_Tabs_Number do
		Historia_HT_JK.list[i] = CreateFrame("Button",nil,Historia_HT_JK)
		Historia_HT_JK.list[i]:SetSize(320,16)
		Historia_HT_JK.list[i]:SetPoint("TOPRIGHT",Historia_HT_JK,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HT_JK.list[i]:Show()
		
		Historia_HT_JK.list[i].name1 = Historia_HT_JK.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HT_JK.list[i].name1:SetSize(112,16)
		Historia_HT_JK.list[i].name1:SetPoint("LEFT",4,0)	
		Historia_HT_JK.list[i].name1:SetJustifyH("LEFT") 
		Historia_HT_JK.list[i].name1:SetText(Historia_Timeline_Tabs_Text[i])
		
		Historia_HT_JK.list[i].name2 = Historia_HT_JK.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HT_JK.list[i].name2:SetSize(40,16)
		Historia_HT_JK.list[i].name2:SetPoint("LEFT", Historia_HT_JK.list[i].name1, "RIGHT",4,0)	
		Historia_HT_JK.list[i].name2:SetJustifyH("CENTER")

		Historia_HT_JK.list[i].name3 = Historia_HT_JK.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HT_JK.list[i].name3:SetSize(160,16)
		Historia_HT_JK.list[i].name3:SetPoint("LEFT", Historia_HT_JK.list[i].name2, "RIGHT",4,0)
		Historia_HT_JK.list[i].name3:SetJustifyH("LEFT") 
	end	
	
	--  Create a frame for the best years days.
	local Historia_HT_JL = CreateFrame("Frame","Historia_HT_JL",Historia_HT_J)
	Historia_HT_JL:SetPoint("TOPLEFT","Historia_HT_JK","BOTTOMLEFT",0,-16)
	Historia_HT_JL:SetPoint("BOTTOMRIGHT","Historia_HT_JK","BOTTOMLEFT",320,-104)
	Historia_HT_JL:SetBackdrop(cfg.Historia_backdrop2)

	Historia_HT_JL.F1 = Historia_HT_JK:CreateFontString(nil,"ARTWORK","GameFontGreen")
	Historia_HT_JL.F1:SetPoint("Top","Historia_HT_JL",0,-4)
	Historia_HT_JL.F1:SetText(L["Best years"])	

	Historia_HT_JL.list = {}
	for i=1,Historia_Timeline_Tabs_Number do
		Historia_HT_JL.list[i] = CreateFrame("Button",nil,Historia_HT_JL)
		Historia_HT_JL.list[i]:SetSize(320,16)
		Historia_HT_JL.list[i]:SetPoint("TOPRIGHT",Historia_HT_JL,"TOPRIGHT",0,(i-1)*-16-20)
		Historia_HT_JL.list[i]:Show()
		
		Historia_HT_JL.list[i].name1 = Historia_HT_JL.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HT_JL.list[i].name1:SetSize(112,16)
		Historia_HT_JL.list[i].name1:SetPoint("LEFT",4,0)	
		Historia_HT_JL.list[i].name1:SetJustifyH("LEFT") 
		Historia_HT_JL.list[i].name1:SetText(Historia_Timeline_Tabs_Text[i])
		
		Historia_HT_JL.list[i].name2 = Historia_HT_JL.list[i]:CreateFontString(nil,"ARTWORK","GameFontWhite")
		Historia_HT_JL.list[i].name2:SetSize(40,16)
		Historia_HT_JL.list[i].name2:SetPoint("LEFT", Historia_HT_JL.list[i].name1, "RIGHT",4,0)	
		Historia_HT_JL.list[i].name2:SetJustifyH("CENTER")

		Historia_HT_JL.list[i].name3 = Historia_HT_JL.list[i]:CreateFontString(nil,"ARTWORK","GameFontNormal")
		Historia_HT_JL.list[i].name3:SetSize(160,16)
		Historia_HT_JL.list[i].name3:SetPoint("LEFT", Historia_HT_JL.list[i].name2, "RIGHT",4,0)
		Historia_HT_JL.list[i].name3:SetJustifyH("LEFT") 
	end		
	
	local Historia_HT_K = CreateFrame("Frame","Historia_HT_K",Historia_HT)
	Historia_HT_K:SetPoint("TOPRIGHT","Historia_HT_J","TOPLEFT",-16,0)
	Historia_HT_K:SetPoint("BOTTOMLEFT","Historia_HT_J", "BOTTOMLEFT",-96,0)	
	Historia_HT_K:SetBackdrop(cfg.Historia_backdrop2)		
	
	Historia_HT_K.list = {}
	for i = 1,6 do
		Historia_HT_K.list[i] = CreateFrame("Button",nil,Historia_HT_K)
		Historia_HT_K.list[i]:SetSize(64,64)
		Historia_HT_K.list[i]:SetPoint("TOP",Historia_HT_K,0,(i-1)*-70-2)
		Historia_HT_K.list[i]:Show()
		
		Historia_HT_K.list[i].te1 = Historia_HT_K.list[i]:CreateTexture(nil,"ARTWORK")
		Historia_HT_K.list[i].te1:SetTexture(cfg.Icons .."challenges-plat")		
		Historia_HT_K.list[i].te1:SetPoint("TOPLEFT",Historia_HT_K.list[i],0,0)
		Historia_HT_K.list[i].te1:SetPoint("BOTTOMRIGHT",Historia_HT_K.list[i],0,0)		
		Historia_HT_K.list[i]:Show()		
	end	
end


-------------------------------------------------------------------------------
--	Fill the rest of the Time line Tab
-------------------------------------------------------------------------------
function Handle_TimeLine_TheRest()
	for i = 1, Historia_NUMBER_OF_YEARS do
		if HistoriaLocalDb.Dates[DTY[i]] then
			Historia_TimeLine_Years_Quests = 0
			Historia_TimeLine_Years_Skills = 0
			Historia_TimeLine_Years_Professions = 0
			Historia_TimeLine_Years_Levels = 0
			for j = 1, Historia_NUMBER_OF_MONTHS do
				if HistoriaLocalDb.Dates[DTY[i]][DTM[j]] then
					Historia_TimeLine_Months_Quests = 0
					Historia_TimeLine_Months_Skills = 0
					Historia_TimeLine_Months_Professions = 0
					Historia_TimeLine_Months_Levels = 0				
					for k = 1, Historia_NUMBER_OF_DAYS do
						if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]] then
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests > 0 then
								Historia_TimeLine_Months_Quests = Historia_TimeLine_Months_Quests + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests
								Historia_TimeLine_Years_Quests = Historia_TimeLine_Years_Quests + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests
								if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests > Best_day_Quests[1] then
									Best_day_Quests[1] = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Quests
									Best_day_Quests[2] = DTY[i]
									Best_day_Quests[3] = DTM[j]
									Best_day_Quests[4] = DTD[k]
								end
							end	
						
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills > 0 then
								Historia_TimeLine_Months_Skills = Historia_TimeLine_Months_Skills + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills
								Historia_TimeLine_Years_Skills = Historia_TimeLine_Years_Skills + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills								
								if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills > Best_day_Skills[1] then
									Best_day_Skills[1] = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Skills
									Best_day_Skills[2] = DTY[i]
									Best_day_Skills[3] = DTM[j]
									Best_day_Skills[4] = DTD[k]
								end
							end
							
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions > 0 then
								Historia_TimeLine_Months_Professions = Historia_TimeLine_Months_Professions + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions
								Historia_TimeLine_Years_Professions = Historia_TimeLine_Years_Professions + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions								
								if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions > Best_day_Professions[1] then
									Best_day_Professions[1] = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Professions
									Best_day_Professions[2] = DTY[i]
									Best_day_Professions[3] = DTM[j]
									Best_day_Professions[4] = DTD[k]
								end							
							end
							
							if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level > 0 then
								Historia_TimeLine_Months_Levels = Historia_TimeLine_Months_Levels + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level
								Historia_TimeLine_Years_Levels = Historia_TimeLine_Years_Levels + HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level								
								if HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level > Best_day_Level[1] then
									Best_day_Level[1] = HistoriaLocalDb.Dates[DTY[i]][DTM[j]][DTD[k]].Level
									Best_day_Level[2] = DTY[i]
									Best_day_Level[3] = DTM[j]
									Best_day_Level[4] = DTD[k]
								end								
							end
						end
					end
					--	Store the collected month data
					if Historia_TimeLine_Months_Quests > 0 then
						if Historia_TimeLine_Months_Quests > Best_month_Quests[1] then
							Best_month_Quests[1] = Historia_TimeLine_Months_Quests
							Best_month_Quests[2] = DTY[i]
							Best_month_Quests[3] = DTM[j]
						end	
					end	
					if Historia_TimeLine_Months_Skills > 0 then
						if Historia_TimeLine_Months_Skills > Best_month_Skills[1] then
							Best_month_Skills[1] = Historia_TimeLine_Months_Skills
							Best_month_Skills[2] = DTY[i]
							Best_month_Skills[3] = DTM[j]
						end	
					end	
					if Historia_TimeLine_Months_Professions > 0 then
						if Historia_TimeLine_Months_Professions > Best_month_Professions[1] then
							Best_month_Professions[1] = Historia_TimeLine_Months_Professions
							Best_month_Professions[2] = DTY[i]
							Best_month_Professions[3] = DTM[j]
						end	
					end	
					if Historia_TimeLine_Months_Levels > 0 then
						if Historia_TimeLine_Months_Levels > Best_month_Level[1] then
							Best_month_Level[1] = Historia_TimeLine_Months_Levels
							Best_month_Level[2] = DTY[i]
							Best_month_Level[3] = DTM[j]
						end	
					end						
				end
			end	
			--	Store the collected year data
			if Historia_TimeLine_Years_Quests > 0 then
				if Historia_TimeLine_Years_Quests > Best_year_Quests[1] then
					Best_year_Quests[1] = Historia_TimeLine_Years_Quests
					Best_year_Quests[2] = DTY[i]
				end	
			end	
			if Historia_TimeLine_Years_Skills > 0 then
				if Historia_TimeLine_Years_Skills > Best_year_Skills[1] then
					Best_year_Skills[1] = Historia_TimeLine_Years_Skills
					Best_year_Skills[2] = DTY[i]
				end	
			end
			if Historia_TimeLine_Years_Professions > 0 then
				if Historia_TimeLine_Years_Professions > Best_year_Professions[1] then
					Best_year_Professions[1] = Historia_TimeLine_Years_Professions
					Best_year_Professions[2] = DTY[i]
				end	
			end
			if Historia_TimeLine_Years_Levels > 0 then
				if Historia_TimeLine_Years_Levels > Best_year_Level[1] then
					Best_year_Level[1] = Historia_TimeLine_Years_Levels
					Best_year_Level[2] = DTY[i]
				end	
			end			
		end	
	end

	if Best_day_Level[1] > -99999 then
		Historia_HT_JJ.list[1].name2:SetText(Best_day_Level[1])
		Historia_HT_JJ.list[1].name3:SetText(cfg.Historia_FormatDate(Best_day_Level[2],Best_day_Level[3],Best_day_Level[4]))
	end	
	if Best_day_Professions[1] > -99999 then
		Historia_HT_JJ.list[2].name2:SetText(Best_day_Professions[1])
		Historia_HT_JJ.list[2].name3:SetText(cfg.Historia_FormatDate(Best_day_Professions[2],Best_day_Professions[3],Best_day_Professions[4]))
	end		
	if Best_day_Skills[1] > -99999 then
		Historia_HT_JJ.list[3].name2:SetText(Best_day_Skills[1])
		Historia_HT_JJ.list[3].name3:SetText(cfg.Historia_FormatDate(Best_day_Skills[2],Best_day_Skills[3],Best_day_Skills[4]))
	end
	if Best_day_Quests[1] > -99999 then
		Historia_HT_JJ.list[4].name2:SetText(Best_day_Quests[1])
		Historia_HT_JJ.list[4].name3:SetText(cfg.Historia_FormatDate(Best_day_Quests[2],Best_day_Quests[3],Best_day_Quests[4]))
	end

	if Best_month_Level[1] > -99999 then
		Historia_HT_JK.list[1].name2:SetText(Best_month_Level[1])
		Historia_HT_JK.list[1].name3:SetText(cfg.Historia_FormatDate(Best_month_Level[2],Best_month_Level[3],""))
	end	
	if Best_month_Professions[1] > -99999 then
		Historia_HT_JK.list[2].name2:SetText(Best_month_Professions[1])
		Historia_HT_JK.list[2].name3:SetText(cfg.Historia_FormatDate(Best_month_Professions[2],Best_month_Professions[3],""))
	end		
	if Best_month_Skills[1] > -99999 then
		Historia_HT_JK.list[3].name2:SetText(Best_month_Skills[1])
		Historia_HT_JK.list[3].name3:SetText(cfg.Historia_FormatDate(Best_month_Skills[2],Best_month_Skills[3],""))
	end	
	if Best_month_Quests[1] > -99999 then
		Historia_HT_JK.list[4].name2:SetText(Best_month_Quests[1])
		Historia_HT_JK.list[4].name3:SetText(cfg.Historia_FormatDate(Best_month_Quests[2],Best_month_Quests[3],""))
	end	
	
	if Best_year_Level[1] > -99999 then
		Historia_HT_JL.list[1].name2:SetText(Best_year_Level[1])
		Historia_HT_JL.list[1].name3:SetText(Best_year_Level[2])
	end	
	if Best_year_Professions[1] > -99999 then
		Historia_HT_JL.list[2].name2:SetText(Best_year_Professions[1])
		Historia_HT_JL.list[2].name3:SetText(Best_year_Professions[2])
	end		
	if Best_year_Skills[1] > -99999 then
		Historia_HT_JL.list[3].name2:SetText(Best_year_Skills[1])
		Historia_HT_JL.list[3].name3:SetText(Best_year_Skills[2])
	end	
	if Best_year_Quests[1] > -99999 then
		Historia_HT_JL.list[4].name2:SetText(Best_year_Quests[1])
		Historia_HT_JL.list[4].name3:SetText(Best_year_Quests[2])
	end	
end


-------------------------------------------------------------------------------
--  Handle the TimeLine Tab
-------------------------------------------------------------------------------
function Historia_HT_Update()
	Historia_HT_Build_Table(1)
	Handle_TimeLine_TheRest()
end
